@@ -3,6 +3,7 @@ package bundler
 import (
 	"testing"
 
+	"github.com/evanw/esbuild/internal/compat"
 	"github.com/evanw/esbuild/internal/config"
 )
 
@@ -1981,3 +1982,500 @@ func TestDCETemplateLiteral(t *testing.T) {
 		},
 	})
 }
+
+// Calls to the runtime "__publicField" function are not considered side effects
+func TestTreeShakingLoweredClassStaticField(t *testing.T) {
+	dce_suite.expectBundled(t, bundled{
+		files: map[string]string{
+			"/entry.js": `
+				class REMOVE_ME {
+					static x = 'x'
+					static y = 'y'
+					static z = 'z'
+				}
+				function REMOVE_ME_TOO() {
+					new REMOVE_ME()
+				}
+				class KeepMe1 {
+					static x = 'x'
+					static y = sideEffects()
+					static z = 'z'
+				}
+				class KeepMe2 {
+					static x = 'x'
+					static y = 'y'
+					static z = 'z'
+				}
+				new KeepMe2()
+			`,
+		},
+		entryPaths: []string{"/entry.js"},
+		options: config.Options{
+			Mode:                  config.ModeBundle,
+			AbsOutputDir:          "/out",
+			UnsupportedJSFeatures: compat.ClassField,
+		},
+	})
+}
+
+func TestTreeShakingLoweredClassStaticFieldMinified(t *testing.T) {
+	dce_suite.expectBundled(t, bundled{
+		files: map[string]string{
+			"/entry.js": `
+				class REMOVE_ME {
+					static x = 'x'
+					static y = 'y'
+					static z = 'z'
+				}
+				function REMOVE_ME_TOO() {
+					new REMOVE_ME()
+				}
+				class KeepMe1 {
+					static x = 'x'
+					static y = sideEffects()
+					static z = 'z'
+				}
+				class KeepMe2 {
+					static x = 'x'
+					static y = 'y'
+					static z = 'z'
+				}
+				new KeepMe2()
+			`,
+		},
+		entryPaths: []string{"/entry.js"},
+		options: config.Options{
+			Mode:                  config.ModeBundle,
+			AbsOutputDir:          "/out",
+			UnsupportedJSFeatures: compat.ClassField,
+			MangleSyntax:          true,
+		},
+	})
+}
+
+// Assignments are considered side effects
+func TestTreeShakingLoweredClassStaticFieldAssignment(t *testing.T) {
+	dce_suite.expectBundled(t, bundled{
+		files: map[string]string{
+			"/entry.ts": `
+				class KeepMe1 {
+					static x = 'x'
+					static y = 'y'
+					static z = 'z'
+				}
+				class KeepMe2 {
+					static x = 'x'
+					static y = sideEffects()
+					static z = 'z'
+				}
+				class KeepMe3 {
+					static x = 'x'
+					static y = 'y'
+					static z = 'z'
+				}
+				new KeepMe3()
+			`,
+		},
+		entryPaths: []string{"/entry.js"},
+		options: config.Options{
+			Mode:                    config.ModeBundle,
+			AbsOutputDir:            "/out",
+			UnsupportedJSFeatures:   compat.ClassField,
+			UseDefineForClassFields: config.False,
+		},
+	})
+}
+
+func TestInlineIdentityFunctionCalls(t *testing.T) {
+	dce_suite.expectBundled(t, bundled{
+		files: map[string]string{
+			"/identity.js": `
+				function DROP(x) { return x }
+				console.log(DROP(1))
+				DROP(foo())
+				DROP(1)
+			`,
+
+			"/identity-last.js": `
+				function DROP(x) { return [x] }
+				function DROP(x) { return x }
+				console.log(DROP(1))
+				DROP(foo())
+				DROP(1)
+			`,
+
+			"/identity-cross-module.js": `
+				import { DROP } from './identity-cross-module-def'
+				console.log(DROP(1))
+				DROP(foo())
+				DROP(1)
+			`,
+
+			"/identity-cross-module-def.js": `
+				export function DROP(x) { return x }
+			`,
+
+			"/identity-no-args.js": `
+				function keep(x) { return x }
+				console.log(keep())
+				keep()
+			`,
+
+			"/identity-two-args.js": `
+				function keep(x) { return x }
+				console.log(keep(1, 2))
+				keep(1, 2)
+			`,
+
+			"/identity-first.js": `
+				function keep(x) { return x }
+				function keep(x) { return [x] }
+				console.log(keep(1))
+				keep(foo())
+				keep(1)
+			`,
+
+			"/identity-generator.js": `
+				function* keep(x) { return x }
+				console.log(keep(1))
+				keep(foo())
+				keep(1)
+			`,
+
+			"/identity-async.js": `
+				async function keep(x) { return x }
+				console.log(keep(1))
+				keep(foo())
+				keep(1)
+			`,
+
+			"/reassign.js": `
+				function keep(x) { return x }
+				keep = reassigned
+				console.log(keep(1))
+				keep(foo())
+				keep(1)
+			`,
+
+			"/reassign-inc.js": `
+				function keep(x) { return x }
+				keep++
+				console.log(keep(1))
+				keep(foo())
+				keep(1)
+			`,
+
+			"/reassign-div.js": `
+				function keep(x) { return x }
+				keep /= reassigned
+				console.log(keep(1))
+				keep(foo())
+				keep(1)
+			`,
+
+			"/reassign-array.js": `
+				function keep(x) { return x }
+				[keep] = reassigned
+				console.log(keep(1))
+				keep(foo())
+				keep(1)
+			`,
+
+			"/reassign-object.js": `
+				function keep(x) { return x }
+				({keep} = reassigned)
+				console.log(keep(1))
+				keep(foo())
+				keep(1)
+			`,
+
+			"/not-identity-two-args.js": `
+				function keep(x, y) { return x }
+				console.log(keep(1))
+				keep(foo())
+				keep(1)
+			`,
+
+			"/not-identity-default.js": `
+				function keep(x = foo()) { return x }
+				console.log(keep(1))
+				keep(foo())
+				keep(1)
+			`,
+
+			"/not-identity-array.js": `
+				function keep([x]) { return x }
+				console.log(keep(1))
+				keep(foo())
+				keep(1)
+			`,
+
+			"/not-identity-object.js": `
+				function keep({x}) { return x }
+				console.log(keep(1))
+				keep(foo())
+				keep(1)
+			`,
+
+			"/not-identity-rest.js": `
+				function keep(...x) { return x }
+				console.log(keep(1))
+				keep(foo())
+				keep(1)
+			`,
+
+			"/not-identity-return.js": `
+				function keep(x) { return [x] }
+				console.log(keep(1))
+				keep(foo())
+				keep(1)
+			`,
+		},
+		entryPaths: []string{
+			"/identity.js",
+			"/identity-last.js",
+			"/identity-first.js",
+			"/identity-generator.js",
+			"/identity-async.js",
+			"/identity-cross-module.js",
+			"/identity-no-args.js",
+			"/identity-two-args.js",
+			"/reassign.js",
+			"/reassign-inc.js",
+			"/reassign-div.js",
+			"/reassign-array.js",
+			"/reassign-object.js",
+			"/not-identity-two-args.js",
+			"/not-identity-default.js",
+			"/not-identity-array.js",
+			"/not-identity-object.js",
+			"/not-identity-rest.js",
+			"/not-identity-return.js",
+		},
+		options: config.Options{
+			Mode:         config.ModeBundle,
+			AbsOutputDir: "/out",
+			MangleSyntax: true,
+		},
+	})
+}
+
+func TestInlineEmptyFunctionCalls(t *testing.T) {
+	dce_suite.expectBundled(t, bundled{
+		files: map[string]string{
+			"/empty.js": `
+				function DROP() {}
+				console.log(DROP(foo(), bar()))
+				console.log(DROP(foo(), 1))
+				console.log(DROP(1, foo()))
+				console.log(DROP(1))
+				console.log(DROP())
+				DROP(foo(), bar())
+				DROP(foo(), 1)
+				DROP(1, foo())
+				DROP(1)
+				DROP()
+			`,
+
+			"/empty-comma.js": `
+				function DROP() {}
+				console.log((DROP(), DROP(), foo()))
+				console.log((DROP(), foo(), DROP()))
+				console.log((foo(), DROP(), DROP()))
+				for (DROP(); DROP(); DROP()) DROP();
+				DROP(), DROP(), foo();
+				DROP(), foo(), DROP();
+				foo(), DROP(), DROP();
+			`,
+
+			"/empty-last.js": `
+				function DROP() { return x }
+				function DROP() { return }
+				console.log(DROP())
+				DROP()
+			`,
+
+			"/empty-cross-module.js": `
+				import { DROP } from './empty-cross-module-def'
+				console.log(DROP())
+				DROP()
+			`,
+
+			"/empty-cross-module-def.js": `
+				export function DROP() {}
+			`,
+
+			"/empty-first.js": `
+				function keep() { return }
+				function keep() { return x }
+				console.log(keep())
+				keep(foo())
+				keep(1)
+			`,
+
+			"/empty-generator.js": `
+				function* keep() {}
+				console.log(keep())
+				keep(foo())
+				keep(1)
+			`,
+
+			"/empty-async.js": `
+				async function keep() {}
+				console.log(keep())
+				keep(foo())
+				keep(1)
+			`,
+
+			"/reassign.js": `
+				function keep() {}
+				keep = reassigned
+				console.log(keep())
+				keep(foo())
+				keep(1)
+			`,
+
+			"/reassign-inc.js": `
+				function keep() {}
+				keep++
+				console.log(keep(1))
+				keep(foo())
+				keep(1)
+			`,
+
+			"/reassign-div.js": `
+				function keep() {}
+				keep /= reassigned
+				console.log(keep(1))
+				keep(foo())
+				keep(1)
+			`,
+
+			"/reassign-array.js": `
+				function keep() {}
+				[keep] = reassigned
+				console.log(keep(1))
+				keep(foo())
+				keep(1)
+			`,
+
+			"/reassign-object.js": `
+				function keep() {}
+				({keep} = reassigned)
+				console.log(keep(1))
+				keep(foo())
+				keep(1)
+			`,
+		},
+		entryPaths: []string{
+			"/empty.js",
+			"/empty-comma.js",
+			"/empty-last.js",
+			"/empty-cross-module.js",
+			"/empty-first.js",
+			"/empty-generator.js",
+			"/empty-async.js",
+			"/reassign.js",
+			"/reassign-inc.js",
+			"/reassign-div.js",
+			"/reassign-array.js",
+			"/reassign-object.js",
+		},
+		options: config.Options{
+			Mode:         config.ModeBundle,
+			AbsOutputDir: "/out",
+			MangleSyntax: true,
+		},
+	})
+}
+
+func TestInlineFunctionCallBehaviorChanges(t *testing.T) {
+	dce_suite.expectBundled(t, bundled{
+		files: map[string]string{
+			"/entry.js": `
+				function empty() {}
+				function id(x) { return x }
+
+				export let shouldBeWrapped = [
+					id(foo.bar)(),
+					id(foo[bar])(),
+					id(foo?.bar)(),
+					id(foo?.[bar])(),
+
+					(empty(), foo.bar)(),
+					(empty(), foo[bar])(),
+					(empty(), foo?.bar)(),
+					(empty(), foo?.[bar])(),
+
+					id(eval)(),
+					id(eval)?.(),
+					(empty(), eval)(),
+					(empty(), eval)?.(),
+
+					id(foo.bar)` + "``" + `,
+					id(foo[bar])` + "``" + `,
+					id(foo?.bar)` + "``" + `,
+					id(foo?.[bar])` + "``" + `,
+
+					(empty(), foo.bar)` + "``" + `,
+					(empty(), foo[bar])` + "``" + `,
+					(empty(), foo?.bar)` + "``" + `,
+					(empty(), foo?.[bar])` + "``" + `,
+
+					delete id(foo),
+					delete id(foo.bar),
+					delete id(foo[bar]),
+					delete id(foo?.bar),
+					delete id(foo?.[bar]),
+
+					delete (empty(), foo),
+					delete (empty(), foo.bar),
+					delete (empty(), foo[bar]),
+					delete (empty(), foo?.bar),
+					delete (empty(), foo?.[bar]),
+
+					delete empty(),
+				]
+
+				export let shouldNotBeWrapped = [
+					id(foo)(),
+					(empty(), foo)(),
+
+					id(foo)` + "``" + `,
+					(empty(), foo)` + "``" + `,
+				]
+
+				export let shouldNotBeDoubleWrapped = [
+					delete (empty(), foo(), bar()),
+					delete id((foo(), bar())),
+				]
+			`,
+		},
+		entryPaths: []string{"/entry.js"},
+		options: config.Options{
+			Mode:         config.ModePassThrough,
+			AbsOutputDir: "/out",
+			MangleSyntax: true,
+		},
+	})
+}
+
+func TestInlineFunctionCallForInitDecl(t *testing.T) {
+	dce_suite.expectBundled(t, bundled{
+		files: map[string]string{
+			"/entry.js": `
+				function empty() {}
+				function id(x) { return x }
+
+				for (var y = empty(); false; ) ;
+				for (var z = id(123); false; ) ;
+			`,
+		},
+		entryPaths: []string{"/entry.js"},
+		options: config.Options{
+			Mode:         config.ModeBundle,
+			AbsOutputDir: "/out",
+			MangleSyntax: true,
+		},
+	})
+}
