@@ -24,18 +24,18 @@ type printer struct {
 }
 
 type Options struct {
-	RemoveWhitespace  bool
-	ASCIIOnly         bool
-	AddSourceMappings bool
-	LegalComments     config.LegalComments
+	// This will be present if the input file had a source map. In that case we
+	// want to map all the way back to the original input file(s).
+	InputSourceMap *sourcemap.SourceMap
 
 	// If we're writing out a source map, this table of line start indices lets
 	// us do binary search on to figure out what line a given AST node came from
 	LineOffsetTables []sourcemap.LineOffsetTable
 
-	// This will be present if the input file had a source map. In that case we
-	// want to map all the way back to the original input file(s).
-	InputSourceMap *sourcemap.SourceMap
+	RemoveWhitespace  bool
+	ASCIIOnly         bool
+	AddSourceMappings bool
+	LegalComments     config.LegalComments
 }
 
 type PrintResult struct {
@@ -290,6 +290,13 @@ func (p *printer) printComplexSelectors(selectors []css_ast.ComplexSelector, ind
 }
 
 func (p *printer) printCompoundSelector(sel css_ast.CompoundSelector, isFirst bool, isLast bool) {
+	if !isFirst && sel.Combinator == "" {
+		// A space is required in between compound selectors if there is no
+		// combinator in the middle. It's fine to convert "a + b" into "a+b"
+		// but not to convert "a b" into "ab".
+		p.print(" ")
+	}
+
 	if sel.HasNestPrefix {
 		p.print("&")
 	}
@@ -302,8 +309,6 @@ func (p *printer) printCompoundSelector(sel css_ast.CompoundSelector, isFirst bo
 		if !p.options.RemoveWhitespace {
 			p.print(" ")
 		}
-	} else if !isFirst {
-		p.print(" ")
 	}
 
 	if sel.TypeSelector != nil {
