@@ -24,7 +24,7 @@ import (
 // has been parsed should create a copy of the mutated parts of the tree
 // instead of mutating the original tree.
 
-type L int
+type L uint8
 
 // https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Operators/Operator_Precedence
 const (
@@ -53,7 +53,7 @@ const (
 	LMember
 )
 
-type OpCode int
+type OpCode uint8
 
 func (op OpCode) IsPrefix() bool {
 	return op < UnOpPostDec
@@ -249,11 +249,11 @@ type LocRef struct {
 }
 
 type Comment struct {
-	Loc  logger.Loc
 	Text string
+	Loc  logger.Loc
 }
 
-type PropertyKind int
+type PropertyKind uint8
 
 const (
 	PropertyNormal PropertyKind = iota
@@ -265,12 +265,11 @@ const (
 )
 
 type ClassStaticBlock struct {
-	Loc   logger.Loc
 	Stmts []Stmt
+	Loc   logger.Loc
 }
 
 type Property struct {
-	TSDecorators     []Expr
 	ClassStaticBlock *ClassStaticBlock
 
 	Key Expr
@@ -289,6 +288,8 @@ type Property struct {
 	//
 	InitializerOrNil Expr
 
+	TSDecorators []Expr
+
 	Kind            PropertyKind
 	IsComputed      bool
 	IsMethod        bool
@@ -307,9 +308,9 @@ type PropertyBinding struct {
 }
 
 type Arg struct {
-	TSDecorators []Expr
 	Binding      Binding
 	DefaultOrNil Expr
+	TSDecorators []Expr
 
 	// "constructor(public x: boolean) {}"
 	IsTypeScriptCtorField bool
@@ -317,10 +318,10 @@ type Arg struct {
 
 type Fn struct {
 	Name         *LocRef
-	OpenParenLoc logger.Loc
 	Args         []Arg
 	Body         FnBody
 	ArgumentsRef Ref
+	OpenParenLoc logger.Loc
 
 	IsAsync     bool
 	IsGenerator bool
@@ -332,17 +333,17 @@ type Fn struct {
 }
 
 type FnBody struct {
-	Loc   logger.Loc
 	Stmts []Stmt
+	Loc   logger.Loc
 }
 
 type Class struct {
-	ClassKeyword logger.Range
 	TSDecorators []Expr
 	Name         *LocRef
 	ExtendsOrNil Expr
-	BodyLoc      logger.Loc
 	Properties   []Property
+	ClassKeyword logger.Range
+	BodyLoc      logger.Loc
 }
 
 type ArrayBinding struct {
@@ -351,8 +352,8 @@ type ArrayBinding struct {
 }
 
 type Binding struct {
-	Loc  logger.Loc
 	Data B
+	Loc  logger.Loc
 }
 
 // This interface is never called. Its purpose is to encode a variant type in
@@ -380,8 +381,8 @@ type BObject struct {
 }
 
 type Expr struct {
-	Loc  logger.Loc
 	Data E
+	Loc  logger.Loc
 }
 
 // This interface is never called. Its purpose is to encode a variant type in
@@ -434,8 +435,8 @@ type EArray struct {
 }
 
 type EUnary struct {
-	Op    OpCode
 	Value Expr
+	Op    OpCode
 }
 
 type EBinary struct {
@@ -649,17 +650,17 @@ type EString struct {
 
 type TemplatePart struct {
 	Value      Expr
-	TailLoc    logger.Loc
-	TailCooked []uint16 // Only use when "TagOrNil" is nil
 	TailRaw    string   // Only use when "TagOrNil" is not nil
+	TailCooked []uint16 // Only use when "TagOrNil" is nil
+	TailLoc    logger.Loc
 }
 
 type ETemplate struct {
 	TagOrNil       Expr
-	HeadLoc        logger.Loc
-	HeadCooked     []uint16 // Only use when "TagOrNil" is nil
 	HeadRaw        string   // Only use when "TagOrNil" is not nil
+	HeadCooked     []uint16 // Only use when "TagOrNil" is nil
 	Parts          []TemplatePart
+	HeadLoc        logger.Loc
 	LegacyOctalLoc logger.Loc
 }
 
@@ -694,8 +695,6 @@ type ERequireResolveString struct {
 }
 
 type EImportString struct {
-	ImportRecordIndex uint32
-
 	// Comments inside "import()" expressions have special meaning for Webpack.
 	// Preserving comments inside these expressions makes it possible to use
 	// esbuild as a TypeScript-to-JavaScript frontend for Webpack to improve
@@ -704,6 +703,8 @@ type EImportString struct {
 	// harmless, easy to maintain, and useful to people. See the Webpack docs for
 	// more info: https://webpack.js.org/api/module-methods/#magic-comments.
 	LeadingInteriorComments []Comment
+
+	ImportRecordIndex uint32
 }
 
 type EImportCall struct {
@@ -1016,8 +1017,8 @@ func JoinAllWithComma(all []Expr) (result Expr) {
 }
 
 type Stmt struct {
-	Loc  logger.Loc
 	Data S
+	Loc  logger.Loc
 }
 
 // This interface is never called. Its purpose is to encode a variant type in
@@ -1092,22 +1093,22 @@ type SExportFrom struct {
 }
 
 type SExportDefault struct {
-	DefaultName LocRef
 	Value       Stmt // May be a SExpr or SFunction or SClass
+	DefaultName LocRef
 }
 
 type ExportStarAlias struct {
-	Loc logger.Loc
-
 	// Although this alias name starts off as being the same as the statement's
 	// namespace symbol, it may diverge if the namespace symbol name is minified.
 	// The original alias name is preserved here to avoid this scenario.
 	OriginalName string
+
+	Loc logger.Loc
 }
 
 type SExportStar struct {
-	NamespaceRef      Ref
 	Alias             *ExportStarAlias
+	NamespaceRef      Ref
 	ImportRecordIndex uint32
 }
 
@@ -1132,23 +1133,23 @@ type SExpr struct {
 }
 
 type EnumValue struct {
-	Name       []uint16
 	ValueOrNil Expr
+	Name       []uint16
 	Ref        Ref
 	Loc        logger.Loc
 }
 
 type SEnum struct {
+	Values   []EnumValue
 	Name     LocRef
 	Arg      Ref
-	Values   []EnumValue
 	IsExport bool
 }
 
 type SNamespace struct {
+	Stmts    []Stmt
 	Name     LocRef
 	Arg      Ref
-	Stmts    []Stmt
 	IsExport bool
 }
 
@@ -1163,8 +1164,8 @@ type SClass struct {
 }
 
 type SLabel struct {
-	Name LocRef
 	Stmt Stmt
+	Name LocRef
 }
 
 type SIf struct {
@@ -1187,10 +1188,10 @@ type SForIn struct {
 }
 
 type SForOf struct {
-	IsAwait bool
 	Init    Stmt // May be a SConst, SLet, SVar, or SExpr
 	Value   Expr
 	Body    Stmt
+	IsAwait bool
 }
 
 type SDoWhile struct {
@@ -1205,8 +1206,8 @@ type SWhile struct {
 
 type SWith struct {
 	Value   Expr
-	BodyLoc logger.Loc
 	Body    Stmt
+	BodyLoc logger.Loc
 }
 
 type Catch struct {
@@ -1217,15 +1218,15 @@ type Catch struct {
 }
 
 type Finally struct {
-	Loc   logger.Loc
 	Stmts []Stmt
+	Loc   logger.Loc
 }
 
 type STry struct {
-	BodyLoc logger.Loc
-	Body    []Stmt
 	Catch   *Catch
 	Finally *Finally
+	Body    []Stmt
+	BodyLoc logger.Loc
 }
 
 type Case struct {
@@ -1235,8 +1236,8 @@ type Case struct {
 
 type SSwitch struct {
 	Test    Expr
-	BodyLoc logger.Loc
 	Cases   []Case
+	BodyLoc logger.Loc
 }
 
 // This object represents all of these types of import statements:
@@ -1250,6 +1251,10 @@ type SSwitch struct {
 // Many parts are optional and can be combined in different ways. The only
 // restriction is that you cannot have both a clause and a star namespace.
 type SImport struct {
+	DefaultName *LocRef
+	Items       *[]ClauseItem
+	StarNameLoc *logger.Loc
+
 	// If this is a star import: This is a Ref for the namespace symbol. The Loc
 	// for the symbol is StarLoc.
 	//
@@ -1258,9 +1263,6 @@ type SImport struct {
 	// when converting this module to a CommonJS module.
 	NamespaceRef Ref
 
-	DefaultName       *LocRef
-	Items             *[]ClauseItem
-	StarNameLoc       *logger.Loc
 	ImportRecordIndex uint32
 	IsSingleLine      bool
 }
@@ -1311,9 +1313,7 @@ func IsSuperCall(stmt Stmt) bool {
 }
 
 type ClauseItem struct {
-	Alias    string
-	AliasLoc logger.Loc
-	Name     LocRef
+	Alias string
 
 	// This is the original name of the symbol stored in "Name". It's needed for
 	// "SExportClause" statements such as this:
@@ -1324,6 +1324,9 @@ type ClauseItem struct {
 	// We need to preserve both aliases in case the symbol is renamed. In this
 	// example, "foo" is "OriginalName" and "bar" is "Alias".
 	OriginalName string
+
+	AliasLoc logger.Loc
+	Name     LocRef
 }
 
 type Decl struct {
@@ -1487,7 +1490,7 @@ const (
 	ImportItemMissing
 )
 
-type SymbolFlags uint8
+type SymbolFlags uint16
 
 const (
 	// Certain symbols must not be renamed or minified. For example, the
@@ -1569,6 +1572,25 @@ const (
 	//   function foo() { console.log(2) }
 	//
 	RemoveOverwrittenFunctionDeclaration
+
+	// This flag is to avoid warning about this symbol more than once. It only
+	// applies to the "module" and "exports" unbound symbols.
+	DidWarnAboutCommonJSInESM
+
+	// If this is present, the symbol could potentially be overwritten. This means
+	// it's not safe to make assumptions about this symbol from the initializer.
+	CouldPotentiallyBeMutated
+
+	// This flags all symbols that were exported from the module using the ES6
+	// "export" keyword, either directly on the declaration or using "export {}".
+	WasExported
+
+	// This means the symbol is a normal function that has no body statements.
+	IsEmptyFunction
+
+	// This means the symbol is a normal function that takes a single argument
+	// and returns that argument.
+	IsIdentityFunction
 )
 
 func (flags SymbolFlags) Has(flag SymbolFlags) bool {
@@ -1577,11 +1599,6 @@ func (flags SymbolFlags) Has(flag SymbolFlags) bool {
 
 // Note: the order of values in this struct matters to reduce struct size.
 type Symbol struct {
-	// This is the name that came from the parser. Printed names may be renamed
-	// during minification or to avoid name collisions. Do not use the original
-	// name during printing.
-	OriginalName string
-
 	// This is used for symbols that represent items in the import clause of an
 	// ES6 import statement. These should always be referenced by EImportIdentifier
 	// instead of an EIdentifier. When this is present, the expression should
@@ -1595,6 +1612,11 @@ type Symbol struct {
 	// if it has a namespace alias.
 	NamespaceAlias *NamespaceAlias
 
+	// This is the name that came from the parser. Printed names may be renamed
+	// during minification or to avoid name collisions. Do not use the original
+	// name during printing.
+	OriginalName string
+
 	// Used by the parser for single pass parsing. Symbols that have been merged
 	// form a linked-list where the last link is the symbol to use. This link is
 	// an invalid ref if it's the last link. If this isn't invalid, you need to
@@ -1624,6 +1646,9 @@ type Symbol struct {
 	// slot namespaces: regular symbols, label symbols, and private symbols.
 	NestedScopeSlot ast.Index32
 
+	// Boolean values should all be flags instead to save space
+	Flags SymbolFlags
+
 	Kind SymbolKind
 
 	// We automatically generate import items for property accesses off of
@@ -1644,9 +1669,6 @@ type Symbol struct {
 	// avoid this. We also need to be able to replace such import items with
 	// undefined, which this status is also used for.
 	ImportItemStatus ImportItemStatus
-
-	// Boolean values should all be flags instead to save space
-	Flags SymbolFlags
 }
 
 // You should call "MergeSymbols" instead of calling this directly
@@ -1696,11 +1718,11 @@ func (a *SlotCounts) UnionMax(b SlotCounts) {
 }
 
 type NamespaceAlias struct {
-	NamespaceRef Ref
 	Alias        string
+	NamespaceRef Ref
 }
 
-type ScopeKind int
+type ScopeKind uint8
 
 const (
 	ScopeBlock ScopeKind = iota
@@ -1727,15 +1749,14 @@ type ScopeMember struct {
 }
 
 type Scope struct {
-	Kind      ScopeKind
+	// This will be non-nil if this is a TypeScript "namespace" or "enum"
+	TSNamespace *TSNamespaceScope
+
 	Parent    *Scope
 	Children  []*Scope
 	Members   map[string]ScopeMember
 	Generated []Ref
 
-	// This will be non-nil if this is a TypeScript "namespace" or "enum"
-	TSNamespace *TSNamespaceScope
-
 	// The location of the "use strict" directive for ExplicitStrictMode
 	UseStrictLoc logger.Loc
 
@@ -1752,6 +1773,7 @@ type Scope struct {
 	ForbidArguments bool
 
 	StrictMode StrictModeKind
+	Kind       ScopeKind
 }
 
 type StrictModeKind uint8
@@ -1759,10 +1781,8 @@ type StrictModeKind uint8
 const (
 	SloppyMode StrictModeKind = iota
 	ExplicitStrictMode
-	ImplicitStrictModeImport
-	ImplicitStrictModeExport
-	ImplicitStrictModeTopLevelAwait
 	ImplicitStrictModeClass
+	ImplicitStrictModeESM
 )
 
 func (s *Scope) RecursiveSetStrictMode(kind StrictModeKind) {
@@ -1809,19 +1829,6 @@ type TSNamespaceScope struct {
 	// This is shared between all sibling namespace blocks
 	ExportedMembers TSNamespaceMembers
 
-	// This is specific to this namespace block. It's the argument of the
-	// immediately-invoked function expression that the namespace block is
-	// compiled into:
-	//
-	//   var ns;
-	//   (function (ns2) {
-	//     ns2.x = 123;
-	//   })(ns || (ns = {}));
-	//
-	// This variable is "ns2" in the above example. It's the symbol to use when
-	// generating property accesses off of this namespace when it's in scope.
-	ArgRef Ref
-
 	// This is a lazily-generated map of identifiers that actually represent
 	// property accesses to this namespace's properties. For example:
 	//
@@ -1848,6 +1855,19 @@ type TSNamespaceScope struct {
 	// is specific to that particular namespace block.
 	LazilyGeneratedProperyAccesses map[string]Ref
 
+	// This is specific to this namespace block. It's the argument of the
+	// immediately-invoked function expression that the namespace block is
+	// compiled into:
+	//
+	//   var ns;
+	//   (function (ns2) {
+	//     ns2.x = 123;
+	//   })(ns || (ns = {}));
+	//
+	// This variable is "ns2" in the above example. It's the symbol to use when
+	// generating property accesses off of this namespace when it's in scope.
+	ArgRef Ref
+
 	// Even though enums are like namespaces and both enums and namespaces allow
 	// implicit references to properties of sibling scopes, they behave like
 	// separate, er, namespaces. Implicit references only work namespace-to-
@@ -1970,12 +1990,30 @@ const (
 	ModuleUnknown ModuleType = iota
 
 	// ".cjs" or ".cts" or "type: commonjs" in package.json
-	ModuleCommonJS
+	ModuleCommonJS_CJS
+	ModuleCommonJS_CTS
+	ModuleCommonJS_PackageJSON
 
 	// ".mjs" or ".mts" or "type: module" in package.json
-	ModuleESM
+	ModuleESM_MJS
+	ModuleESM_MTS
+	ModuleESM_PackageJSON
 )
 
+func (mt ModuleType) IsCommonJS() bool {
+	return mt >= ModuleCommonJS_CJS && mt <= ModuleCommonJS_PackageJSON
+}
+
+func (mt ModuleType) IsESM() bool {
+	return mt >= ModuleESM_MJS && mt <= ModuleESM_PackageJSON
+}
+
+type ModuleTypeData struct {
+	Source *logger.Source
+	Range  logger.Range
+	Type   ModuleType
+}
+
 // This is the index to the automatically-generated part containing code that
 // calls "__export(exports, { ... getters ... })". This is used to generate
 // getters on an exports object for ES6 export statements, and is both for
@@ -1984,35 +2022,22 @@ const (
 const NSExportPartIndex = uint32(0)
 
 type AST struct {
-	ApproximateLineCount  int32
-	NestedScopeSlotCounts SlotCounts
-	HasLazyExport         bool
-	ModuleType            ModuleType
+	ModuleTypeData ModuleTypeData
+	Parts          []Part
+	Symbols        []Symbol
+	ModuleScope    *Scope
+	CharFreq       *CharFreq
 
-	// This is a list of CommonJS features. When a file uses CommonJS features,
-	// it's not a candidate for "flat bundling" and must be wrapped in its own
-	// closure. Note that this also includes top-level "return" but these aren't
-	// here because only the parser checks those.
-	UsesExportsRef bool
-	UsesModuleRef  bool
-	ExportsKind    ExportsKind
+	Hashbang  string
+	Directive string
+	URLForCSS string
 
-	// This is a list of ES6 features. They are ranges instead of booleans so
-	// that they can be used in log messages. Check to see if "Len > 0".
-	ImportKeyword        logger.Range // Does not include TypeScript-specific syntax or "import()"
-	ExportKeyword        logger.Range // Does not include TypeScript-specific syntax
-	TopLevelAwaitKeyword logger.Range
-
-	Hashbang    string
-	Directive   string
-	URLForCSS   string
-	Parts       []Part
-	Symbols     []Symbol
-	ModuleScope *Scope
-	CharFreq    *CharFreq
-	ExportsRef  Ref
-	ModuleRef   Ref
-	WrapperRef  Ref
+	// Note: If you're in the linker, do not use this map directly. This map is
+	// filled in by the parser and is considered immutable. For performance reasons,
+	// the linker doesn't mutate this map (cloning a map is slow in Go). Instead the
+	// linker super-imposes relevant information on top in a method call. You should
+	// call "TopLevelSymbolToParts" instead.
+	TopLevelSymbolToPartsFromParser map[Ref][]uint32
 
 	// This contains all top-level exported TypeScript enum constants. It exists
 	// to enable cross-module inlining of constant enums.
@@ -2029,14 +2054,28 @@ type AST struct {
 	NamedExports            map[string]NamedExport
 	ExportStarImportRecords []uint32
 
-	// Note: If you're in the linker, do not use this map directly. This map is
-	// filled in by the parser and is considered immutable. For performance reasons,
-	// the linker doesn't mutate this map (cloning a map is slow in Go). Instead the
-	// linker super-imposes relevant information on top in a method call. You should
-	// call "TopLevelSymbolToParts" instead.
-	TopLevelSymbolToPartsFromParser map[Ref][]uint32
-
 	SourceMapComment logger.Span
+
+	// This is a list of ES6 features. They are ranges instead of booleans so
+	// that they can be used in log messages. Check to see if "Len > 0".
+	ExportKeyword        logger.Range // Does not include TypeScript-specific syntax
+	TopLevelAwaitKeyword logger.Range
+
+	ExportsRef Ref
+	ModuleRef  Ref
+	WrapperRef Ref
+
+	ApproximateLineCount  int32
+	NestedScopeSlotCounts SlotCounts
+	HasLazyExport         bool
+
+	// This is a list of CommonJS features. When a file uses CommonJS features,
+	// it's not a candidate for "flat bundling" and must be wrapped in its own
+	// closure. Note that this also includes top-level "return" but these aren't
+	// here because only the parser checks those.
+	UsesExportsRef bool
+	UsesModuleRef  bool
+	ExportsKind    ExportsKind
 }
 
 type TSEnumValue struct {
@@ -2087,9 +2126,9 @@ var DefaultNameMinifier = NameMinifier{
 }
 
 type charAndCount struct {
-	index byte
-	count int32
 	char  string
+	count int32
+	index byte
 }
 
 // This type is just so we can use Go's native sort function
@@ -2143,10 +2182,11 @@ func (minifier *NameMinifier) NumberToMinifiedName(i int) string {
 }
 
 type NamedImport struct {
+	Alias string
+
 	// Parts within this file that use this import
 	LocalPartsWithUses []uint32
 
-	Alias             string
 	AliasLoc          logger.Loc
 	NamespaceRef      Ref
 	ImportRecordIndex uint32
@@ -2188,6 +2228,17 @@ type Part struct {
 	// An estimate of the number of uses of all symbols used within this part.
 	SymbolUses map[Ref]SymbolUse
 
+	// An estimate of the number of uses of all symbols used as the target of
+	// function calls within this part.
+	SymbolCallUses map[Ref]SymbolCallUse
+
+	// This tracks property accesses off of imported symbols. We don't know
+	// during parsing if an imported symbol is going to be an inlined enum
+	// value or not. This is only known during linking. So we defer adding
+	// a dependency on these imported symbols until we know whether the
+	// property access is an inlined enum value or not.
+	ImportSymbolPropertyUses map[Ref]map[string]SymbolUse
+
 	// The indices of the other parts in this file that are needed if this part
 	// is needed.
 	Dependencies []Dependency
@@ -2221,6 +2272,11 @@ type SymbolUse struct {
 	CountEstimate uint32
 }
 
+type SymbolCallUse struct {
+	CallCountEstimate          uint32
+	SingleArgCallCountEstimate uint32
+}
+
 // Returns the canonical ref that represents the ref for the provided symbol.
 // This may not be the provided ref if the symbol has been merged with another
 // symbol.
@@ -2385,3 +2441,356 @@ func ConvertBindingToExpr(binding Binding, wrapIdentifier func(logger.Loc, Ref)
 		panic("Internal error")
 	}
 }
+
+// Returns true if this expression is known to result in a primitive value (i.e.
+// null, undefined, boolean, number, bigint, or string), even if the expression
+// cannot be removed due to side effects.
+func IsPrimitiveWithSideEffects(data E) bool {
+	switch e := data.(type) {
+	case *EInlinedEnum:
+		return IsPrimitiveWithSideEffects(e.Value.Data)
+
+	case *ENull, *EUndefined, *EBoolean, *ENumber, *EBigInt, *EString:
+		return true
+
+	case *EUnary:
+		switch e.Op {
+		case
+			// Number or bigint
+			UnOpPos, UnOpNeg, UnOpCpl,
+			UnOpPreDec, UnOpPreInc, UnOpPostDec, UnOpPostInc,
+			// Boolean
+			UnOpNot, UnOpDelete,
+			// Undefined
+			UnOpVoid,
+			// String
+			UnOpTypeof:
+			return true
+		}
+
+	case *EBinary:
+		switch e.Op {
+		case
+			// Boolean
+			BinOpLt, BinOpLe, BinOpGt, BinOpGe, BinOpIn,
+			BinOpInstanceof, BinOpLooseEq, BinOpLooseNe, BinOpStrictEq, BinOpStrictNe,
+			// String, number, or bigint
+			BinOpAdd, BinOpAddAssign,
+			// Number or bigint
+			BinOpSub, BinOpMul, BinOpDiv, BinOpRem, BinOpPow,
+			BinOpSubAssign, BinOpMulAssign, BinOpDivAssign, BinOpRemAssign, BinOpPowAssign,
+			BinOpShl, BinOpShr, BinOpUShr,
+			BinOpShlAssign, BinOpShrAssign, BinOpUShrAssign,
+			BinOpBitwiseOr, BinOpBitwiseAnd, BinOpBitwiseXor,
+			BinOpBitwiseOrAssign, BinOpBitwiseAndAssign, BinOpBitwiseXorAssign:
+			return true
+
+		// These always return one of the arguments unmodified
+		case BinOpLogicalAnd, BinOpLogicalOr, BinOpNullishCoalescing,
+			BinOpLogicalAndAssign, BinOpLogicalOrAssign, BinOpNullishCoalescingAssign:
+			return IsPrimitiveWithSideEffects(e.Left.Data) && IsPrimitiveWithSideEffects(e.Right.Data)
+
+		case BinOpComma:
+			return IsPrimitiveWithSideEffects(e.Right.Data)
+		}
+
+	case *EIf:
+		return IsPrimitiveWithSideEffects(e.Yes.Data) && IsPrimitiveWithSideEffects(e.No.Data)
+	}
+
+	return false
+}
+
+// This will return a nil expression if the expression can be totally removed
+func SimplifyUnusedExpr(expr Expr, isUnbound func(Ref) bool) Expr {
+	switch e := expr.Data.(type) {
+	case *EInlinedEnum:
+		return SimplifyUnusedExpr(e.Value, isUnbound)
+
+	case *ENull, *EUndefined, *EMissing, *EBoolean, *ENumber, *EBigInt,
+		*EString, *EThis, *ERegExp, *EFunction, *EArrow, *EImportMeta:
+		return Expr{}
+
+	case *EDot:
+		if e.CanBeRemovedIfUnused {
+			return Expr{}
+		}
+
+	case *EIdentifier:
+		if e.MustKeepDueToWithStmt {
+			break
+		}
+		if e.CanBeRemovedIfUnused || !isUnbound(e.Ref) {
+			return Expr{}
+		}
+
+	case *ETemplate:
+		if e.TagOrNil.Data == nil {
+			var comma Expr
+			var templateLoc logger.Loc
+			var template *ETemplate
+			for _, part := range e.Parts {
+				// If we know this value is some kind of primitive, then we know that
+				// "ToString" has no side effects and can be avoided.
+				if KnownPrimitiveType(part.Value) != PrimitiveUnknown {
+					if template != nil {
+						comma = JoinWithComma(comma, Expr{Loc: templateLoc, Data: template})
+						template = nil
+					}
+					comma = JoinWithComma(comma, SimplifyUnusedExpr(part.Value, isUnbound))
+					continue
+				}
+
+				// Make sure "ToString" is still evaluated on the value. We can't use
+				// string addition here because that may evaluate "ValueOf" instead.
+				if template == nil {
+					template = &ETemplate{}
+					templateLoc = part.Value.Loc
+				}
+				template.Parts = append(template.Parts, TemplatePart{Value: part.Value})
+			}
+			if template != nil {
+				comma = JoinWithComma(comma, Expr{Loc: templateLoc, Data: template})
+			}
+			return comma
+		}
+
+	case *EArray:
+		// Arrays with "..." spread expressions can't be unwrapped because the
+		// "..." triggers code evaluation via iterators. In that case, just trim
+		// the other items instead and leave the array expression there.
+		for _, spread := range e.Items {
+			if _, ok := spread.Data.(*ESpread); ok {
+				end := 0
+				for _, item := range e.Items {
+					item = SimplifyUnusedExpr(item, isUnbound)
+					if item.Data != nil {
+						e.Items[end] = item
+						end++
+					}
+				}
+				e.Items = e.Items[:end]
+				return expr
+			}
+		}
+
+		// Otherwise, the array can be completely removed. We only need to keep any
+		// array items with side effects. Apply this simplification recursively.
+		var result Expr
+		for _, item := range e.Items {
+			result = JoinWithComma(result, SimplifyUnusedExpr(item, isUnbound))
+		}
+		return result
+
+	case *EObject:
+		// Objects with "..." spread expressions can't be unwrapped because the
+		// "..." triggers code evaluation via getters. In that case, just trim
+		// the other items instead and leave the object expression there.
+		for _, spread := range e.Properties {
+			if spread.Kind == PropertySpread {
+				end := 0
+				for _, property := range e.Properties {
+					// Spread properties must always be evaluated
+					if property.Kind != PropertySpread {
+						value := SimplifyUnusedExpr(property.ValueOrNil, isUnbound)
+						if value.Data != nil {
+							// Keep the value
+							property.ValueOrNil = value
+						} else if !property.IsComputed {
+							// Skip this property if the key doesn't need to be computed
+							continue
+						} else {
+							// Replace values without side effects with "0" because it's short
+							property.ValueOrNil.Data = &ENumber{}
+						}
+					}
+					e.Properties[end] = property
+					end++
+				}
+				e.Properties = e.Properties[:end]
+				return expr
+			}
+		}
+
+		// Otherwise, the object can be completely removed. We only need to keep any
+		// object properties with side effects. Apply this simplification recursively.
+		var result Expr
+		for _, property := range e.Properties {
+			if property.IsComputed {
+				// Make sure "ToString" is still evaluated on the key
+				result = JoinWithComma(result, Expr{Loc: property.Key.Loc, Data: &EBinary{
+					Op:    BinOpAdd,
+					Left:  property.Key,
+					Right: Expr{Loc: property.Key.Loc, Data: &EString{}},
+				}})
+			}
+			result = JoinWithComma(result, SimplifyUnusedExpr(property.ValueOrNil, isUnbound))
+		}
+		return result
+
+	case *EIf:
+		e.Yes = SimplifyUnusedExpr(e.Yes, isUnbound)
+		e.No = SimplifyUnusedExpr(e.No, isUnbound)
+
+		// "foo() ? 1 : 2" => "foo()"
+		if e.Yes.Data == nil && e.No.Data == nil {
+			return SimplifyUnusedExpr(e.Test, isUnbound)
+		}
+
+		// "foo() ? 1 : bar()" => "foo() || bar()"
+		if e.Yes.Data == nil {
+			return JoinWithLeftAssociativeOp(BinOpLogicalOr, e.Test, e.No)
+		}
+
+		// "foo() ? bar() : 2" => "foo() && bar()"
+		if e.No.Data == nil {
+			return JoinWithLeftAssociativeOp(BinOpLogicalAnd, e.Test, e.Yes)
+		}
+
+	case *EUnary:
+		switch e.Op {
+		// These operators must not have any type conversions that can execute code
+		// such as "toString" or "valueOf". They must also never throw any exceptions.
+		case UnOpVoid, UnOpNot:
+			return SimplifyUnusedExpr(e.Value, isUnbound)
+
+		case UnOpTypeof:
+			if _, ok := e.Value.Data.(*EIdentifier); ok {
+				// "typeof x" must not be transformed into if "x" since doing so could
+				// cause an exception to be thrown. Instead we can just remove it since
+				// "typeof x" is special-cased in the standard to never throw.
+				return Expr{}
+			}
+			return SimplifyUnusedExpr(e.Value, isUnbound)
+		}
+
+	case *EBinary:
+		switch e.Op {
+		// These operators must not have any type conversions that can execute code
+		// such as "toString" or "valueOf". They must also never throw any exceptions.
+		case BinOpStrictEq, BinOpStrictNe, BinOpComma:
+			return JoinWithComma(SimplifyUnusedExpr(e.Left, isUnbound), SimplifyUnusedExpr(e.Right, isUnbound))
+
+		// We can simplify "==" and "!=" even though they can call "toString" and/or
+		// "valueOf" if we can statically determine that the types of both sides are
+		// primitives. In that case there won't be any chance for user-defined
+		// "toString" and/or "valueOf" to be called.
+		case BinOpLooseEq, BinOpLooseNe:
+			if IsPrimitiveWithSideEffects(e.Left.Data) && IsPrimitiveWithSideEffects(e.Right.Data) {
+				return JoinWithComma(SimplifyUnusedExpr(e.Left, isUnbound), SimplifyUnusedExpr(e.Right, isUnbound))
+			}
+
+		case BinOpLogicalAnd, BinOpLogicalOr, BinOpNullishCoalescing:
+			// Preserve short-circuit behavior: the left expression is only unused if
+			// the right expression can be completely removed. Otherwise, the left
+			// expression is important for the branch.
+			e.Right = SimplifyUnusedExpr(e.Right, isUnbound)
+			if e.Right.Data == nil {
+				return SimplifyUnusedExpr(e.Left, isUnbound)
+			}
+
+		case BinOpAdd:
+			if result, isStringAddition := simplifyUnusedStringAdditionChain(expr); isStringAddition {
+				return result
+			}
+		}
+
+	case *ECall:
+		// A call that has been marked "__PURE__" can be removed if all arguments
+		// can be removed. The annotation causes us to ignore the target.
+		if e.CanBeUnwrappedIfUnused {
+			expr = Expr{}
+			for _, arg := range e.Args {
+				expr = JoinWithComma(expr, SimplifyUnusedExpr(arg, isUnbound))
+			}
+		}
+
+		// Attempt to shorten IIFEs
+		if len(e.Args) == 0 {
+			switch target := e.Target.Data.(type) {
+			case *EFunction:
+				if len(target.Fn.Args) != 0 {
+					break
+				}
+
+				// Just delete "(function() {})()" completely
+				if len(target.Fn.Body.Stmts) == 0 {
+					return Expr{}
+				}
+
+			case *EArrow:
+				if len(target.Args) != 0 {
+					break
+				}
+
+				// Just delete "(() => {})()" completely
+				if len(target.Body.Stmts) == 0 {
+					return Expr{}
+				}
+
+				if len(target.Body.Stmts) == 1 {
+					switch s := target.Body.Stmts[0].Data.(type) {
+					case *SExpr:
+						if !target.IsAsync {
+							// Replace "(() => { foo() })()" with "foo()"
+							return s.Value
+						} else {
+							// Replace "(async () => { foo() })()" with "(async () => foo())()"
+							target.Body.Stmts[0].Data = &SReturn{ValueOrNil: s.Value}
+							target.PreferExpr = true
+						}
+
+					case *SReturn:
+						if !target.IsAsync {
+							// Replace "(() => foo())()" with "foo()"
+							return s.ValueOrNil
+						}
+					}
+				}
+			}
+		}
+
+	case *ENew:
+		// A constructor call that has been marked "__PURE__" can be removed if all
+		// arguments can be removed. The annotation causes us to ignore the target.
+		if e.CanBeUnwrappedIfUnused {
+			expr = Expr{}
+			for _, arg := range e.Args {
+				expr = JoinWithComma(expr, SimplifyUnusedExpr(arg, isUnbound))
+			}
+		}
+	}
+
+	return expr
+}
+
+func simplifyUnusedStringAdditionChain(expr Expr) (Expr, bool) {
+	switch e := expr.Data.(type) {
+	case *EString:
+		// "'x' + y" => "'' + y"
+		return Expr{Loc: expr.Loc, Data: &EString{}}, true
+
+	case *EBinary:
+		if e.Op == BinOpAdd {
+			left, leftIsStringAddition := simplifyUnusedStringAdditionChain(e.Left)
+			e.Left = left
+
+			if _, rightIsString := e.Right.Data.(*EString); rightIsString {
+				// "('' + x) + 'y'" => "'' + x"
+				if leftIsStringAddition {
+					return left, true
+				}
+
+				// "x + 'y'" => "x + ''"
+				if !leftIsStringAddition {
+					e.Right.Data = &EString{}
+					return expr, true
+				}
+			}
+
+			return expr, leftIsStringAddition
+		}
+	}
+
+	return expr, false
+}
