@@ -60,8 +60,8 @@ func expectLexerError(t *testing.T, contents string, expected string) {
 }
 
 func TestComment(t *testing.T) {
-	expectLexerError(t, "/*", "<stdin>: error: Expected \"*/\" to terminate multi-line comment\n<stdin>: note: The multi-line comment starts here\n")
-	expectLexerError(t, "/*/", "<stdin>: error: Expected \"*/\" to terminate multi-line comment\n<stdin>: note: The multi-line comment starts here\n")
+	expectLexerError(t, "/*", "<stdin>: ERROR: Expected \"*/\" to terminate multi-line comment\n<stdin>: NOTE: The multi-line comment starts here:\n")
+	expectLexerError(t, "/*/", "<stdin>: ERROR: Expected \"*/\" to terminate multi-line comment\n<stdin>: NOTE: The multi-line comment starts here:\n")
 	expectLexerError(t, "/**/", "")
 	expectLexerError(t, "//", "")
 }
@@ -91,7 +91,7 @@ func TestHashbang(t *testing.T) {
 	expectHashbang(t, "#!/usr/bin/env node", "#!/usr/bin/env node")
 	expectHashbang(t, "#!/usr/bin/env node\n", "#!/usr/bin/env node")
 	expectHashbang(t, "#!/usr/bin/env node\nlet x", "#!/usr/bin/env node")
-	expectLexerError(t, " #!/usr/bin/env node", "<stdin>: error: Syntax error \"!\"\n")
+	expectLexerError(t, " #!/usr/bin/env node", "<stdin>: ERROR: Syntax error \"!\"\n")
 }
 
 func expectIdentifier(t *testing.T, contents string, expected string) {
@@ -122,12 +122,12 @@ func TestIdentifier(t *testing.T) {
 	expectIdentifier(t, "t\\u0065st", "test")
 	expectIdentifier(t, "t\\u{65}st", "test")
 
-	expectLexerError(t, "t\\u.", "<stdin>: error: Syntax error \".\"\n")
-	expectLexerError(t, "t\\u0.", "<stdin>: error: Syntax error \".\"\n")
-	expectLexerError(t, "t\\u00.", "<stdin>: error: Syntax error \".\"\n")
-	expectLexerError(t, "t\\u006.", "<stdin>: error: Syntax error \".\"\n")
-	expectLexerError(t, "t\\u{.", "<stdin>: error: Syntax error \".\"\n")
-	expectLexerError(t, "t\\u{0.", "<stdin>: error: Syntax error \".\"\n")
+	expectLexerError(t, "t\\u.", "<stdin>: ERROR: Syntax error \".\"\n")
+	expectLexerError(t, "t\\u0.", "<stdin>: ERROR: Syntax error \".\"\n")
+	expectLexerError(t, "t\\u00.", "<stdin>: ERROR: Syntax error \".\"\n")
+	expectLexerError(t, "t\\u006.", "<stdin>: ERROR: Syntax error \".\"\n")
+	expectLexerError(t, "t\\u{.", "<stdin>: ERROR: Syntax error \".\"\n")
+	expectLexerError(t, "t\\u{0.", "<stdin>: ERROR: Syntax error \".\"\n")
 
 	expectIdentifier(t, "a\u200C", "a\u200C")
 	expectIdentifier(t, "a\u200D", "a\u200D")
@@ -177,31 +177,31 @@ func TestNumericLiteral(t *testing.T) {
 	expectNumber(t, "0B00101", 5.0)
 	expectNumber(t, "0b1011101011101011101011101011101011101", 100352251741.0)
 	expectNumber(t, "0B1011101011101011101011101011101011101", 100352251741.0)
-	expectLexerError(t, "0b", "<stdin>: error: Unexpected end of file\n")
-	expectLexerError(t, "0B", "<stdin>: error: Unexpected end of file\n")
-	expectLexerError(t, "0b012", "<stdin>: error: Syntax error \"2\"\n")
-	expectLexerError(t, "0b018", "<stdin>: error: Syntax error \"8\"\n")
-	expectLexerError(t, "0b01a", "<stdin>: error: Syntax error \"a\"\n")
-	expectLexerError(t, "0b01A", "<stdin>: error: Syntax error \"A\"\n")
+	expectLexerError(t, "0b", "<stdin>: ERROR: Unexpected end of file\n")
+	expectLexerError(t, "0B", "<stdin>: ERROR: Unexpected end of file\n")
+	expectLexerError(t, "0b012", "<stdin>: ERROR: Syntax error \"2\"\n")
+	expectLexerError(t, "0b018", "<stdin>: ERROR: Syntax error \"8\"\n")
+	expectLexerError(t, "0b01a", "<stdin>: ERROR: Syntax error \"a\"\n")
+	expectLexerError(t, "0b01A", "<stdin>: ERROR: Syntax error \"A\"\n")
 
 	expectNumber(t, "0o12345", 5349.0)
 	expectNumber(t, "0O12345", 5349.0)
 	expectNumber(t, "0o1234567654321", 89755965649.0)
 	expectNumber(t, "0O1234567654321", 89755965649.0)
-	expectLexerError(t, "0o", "<stdin>: error: Unexpected end of file\n")
-	expectLexerError(t, "0O", "<stdin>: error: Unexpected end of file\n")
-	expectLexerError(t, "0o018", "<stdin>: error: Syntax error \"8\"\n")
-	expectLexerError(t, "0o01a", "<stdin>: error: Syntax error \"a\"\n")
-	expectLexerError(t, "0o01A", "<stdin>: error: Syntax error \"A\"\n")
+	expectLexerError(t, "0o", "<stdin>: ERROR: Unexpected end of file\n")
+	expectLexerError(t, "0O", "<stdin>: ERROR: Unexpected end of file\n")
+	expectLexerError(t, "0o018", "<stdin>: ERROR: Syntax error \"8\"\n")
+	expectLexerError(t, "0o01a", "<stdin>: ERROR: Syntax error \"a\"\n")
+	expectLexerError(t, "0o01A", "<stdin>: ERROR: Syntax error \"A\"\n")
 
 	expectNumber(t, "0x12345678", float64(0x12345678))
 	expectNumber(t, "0xFEDCBA987", float64(0xFEDCBA987))
 	expectNumber(t, "0x000012345678", float64(0x12345678))
 	expectNumber(t, "0x123456781234", float64(0x123456781234))
-	expectLexerError(t, "0x", "<stdin>: error: Unexpected end of file\n")
-	expectLexerError(t, "0X", "<stdin>: error: Unexpected end of file\n")
-	expectLexerError(t, "0xGFEDCBA", "<stdin>: error: Syntax error \"G\"\n")
-	expectLexerError(t, "0xABCDEFG", "<stdin>: error: Syntax error \"G\"\n")
+	expectLexerError(t, "0x", "<stdin>: ERROR: Unexpected end of file\n")
+	expectLexerError(t, "0X", "<stdin>: ERROR: Unexpected end of file\n")
+	expectLexerError(t, "0xGFEDCBA", "<stdin>: ERROR: Syntax error \"G\"\n")
+	expectLexerError(t, "0xABCDEFG", "<stdin>: ERROR: Syntax error \"G\"\n")
 
 	expectNumber(t, "123.", 123.0)
 	expectNumber(t, ".0123", 0.0123)
@@ -255,28 +255,28 @@ func TestNumericLiteral(t *testing.T) {
 	expectNumber(t, "1.1e+1", 11.0)
 	expectNumber(t, "1.1e-1", 0.11)
 
-	expectLexerError(t, "1e", "<stdin>: error: Unexpected end of file\n")
-	expectLexerError(t, ".1e", "<stdin>: error: Unexpected end of file\n")
-	expectLexerError(t, "1.e", "<stdin>: error: Unexpected end of file\n")
-	expectLexerError(t, "1.1e", "<stdin>: error: Unexpected end of file\n")
-	expectLexerError(t, "1e+", "<stdin>: error: Unexpected end of file\n")
-	expectLexerError(t, ".1e+", "<stdin>: error: Unexpected end of file\n")
-	expectLexerError(t, "1.e+", "<stdin>: error: Unexpected end of file\n")
-	expectLexerError(t, "1.1e+", "<stdin>: error: Unexpected end of file\n")
-	expectLexerError(t, "1e-", "<stdin>: error: Unexpected end of file\n")
-	expectLexerError(t, ".1e-", "<stdin>: error: Unexpected end of file\n")
-	expectLexerError(t, "1.e-", "<stdin>: error: Unexpected end of file\n")
-	expectLexerError(t, "1.1e-", "<stdin>: error: Unexpected end of file\n")
-	expectLexerError(t, "1e+-1", "<stdin>: error: Syntax error \"-\"\n")
-	expectLexerError(t, "1e-+1", "<stdin>: error: Syntax error \"+\"\n")
+	expectLexerError(t, "1e", "<stdin>: ERROR: Unexpected end of file\n")
+	expectLexerError(t, ".1e", "<stdin>: ERROR: Unexpected end of file\n")
+	expectLexerError(t, "1.e", "<stdin>: ERROR: Unexpected end of file\n")
+	expectLexerError(t, "1.1e", "<stdin>: ERROR: Unexpected end of file\n")
+	expectLexerError(t, "1e+", "<stdin>: ERROR: Unexpected end of file\n")
+	expectLexerError(t, ".1e+", "<stdin>: ERROR: Unexpected end of file\n")
+	expectLexerError(t, "1.e+", "<stdin>: ERROR: Unexpected end of file\n")
+	expectLexerError(t, "1.1e+", "<stdin>: ERROR: Unexpected end of file\n")
+	expectLexerError(t, "1e-", "<stdin>: ERROR: Unexpected end of file\n")
+	expectLexerError(t, ".1e-", "<stdin>: ERROR: Unexpected end of file\n")
+	expectLexerError(t, "1.e-", "<stdin>: ERROR: Unexpected end of file\n")
+	expectLexerError(t, "1.1e-", "<stdin>: ERROR: Unexpected end of file\n")
+	expectLexerError(t, "1e+-1", "<stdin>: ERROR: Syntax error \"-\"\n")
+	expectLexerError(t, "1e-+1", "<stdin>: ERROR: Syntax error \"+\"\n")
 
-	expectLexerError(t, "1z", "<stdin>: error: Syntax error \"z\"\n")
-	expectLexerError(t, "1.z", "<stdin>: error: Syntax error \"z\"\n")
-	expectLexerError(t, "1.0f", "<stdin>: error: Syntax error \"f\"\n")
-	expectLexerError(t, "0b1z", "<stdin>: error: Syntax error \"z\"\n")
-	expectLexerError(t, "0o1z", "<stdin>: error: Syntax error \"z\"\n")
-	expectLexerError(t, "0x1z", "<stdin>: error: Syntax error \"z\"\n")
-	expectLexerError(t, "1e1z", "<stdin>: error: Syntax error \"z\"\n")
+	expectLexerError(t, "1z", "<stdin>: ERROR: Syntax error \"z\"\n")
+	expectLexerError(t, "1.z", "<stdin>: ERROR: Syntax error \"z\"\n")
+	expectLexerError(t, "1.0f", "<stdin>: ERROR: Syntax error \"f\"\n")
+	expectLexerError(t, "0b1z", "<stdin>: ERROR: Syntax error \"z\"\n")
+	expectLexerError(t, "0o1z", "<stdin>: ERROR: Syntax error \"z\"\n")
+	expectLexerError(t, "0x1z", "<stdin>: ERROR: Syntax error \"z\"\n")
+	expectLexerError(t, "1e1z", "<stdin>: ERROR: Syntax error \"z\"\n")
 
 	expectNumber(t, "1_2_3", 123)
 	expectNumber(t, ".1_2", 0.12)
@@ -293,51 +293,51 @@ func TestNumericLiteral(t *testing.T) {
 	expectNumber(t, "08.0_1", 8.01)
 	expectNumber(t, "09.0_1", 9.01)
 
-	expectLexerError(t, "0_0", "<stdin>: error: Syntax error \"_\"\n")
-	expectLexerError(t, "0_1", "<stdin>: error: Syntax error \"_\"\n")
-	expectLexerError(t, "0_7", "<stdin>: error: Syntax error \"_\"\n")
-	expectLexerError(t, "0_8", "<stdin>: error: Syntax error \"_\"\n")
-	expectLexerError(t, "0_9", "<stdin>: error: Syntax error \"_\"\n")
-	expectLexerError(t, "00_0", "<stdin>: error: Syntax error \"_\"\n")
-	expectLexerError(t, "01_0", "<stdin>: error: Syntax error \"_\"\n")
-	expectLexerError(t, "07_0", "<stdin>: error: Syntax error \"_\"\n")
-	expectLexerError(t, "08_0", "<stdin>: error: Syntax error \"_\"\n")
-	expectLexerError(t, "09_0", "<stdin>: error: Syntax error \"_\"\n")
-	expectLexerError(t, "08_0.1", "<stdin>: error: Syntax error \"_\"\n")
-	expectLexerError(t, "09_0.1", "<stdin>: error: Syntax error \"_\"\n")
+	expectLexerError(t, "0_0", "<stdin>: ERROR: Syntax error \"_\"\n")
+	expectLexerError(t, "0_1", "<stdin>: ERROR: Syntax error \"_\"\n")
+	expectLexerError(t, "0_7", "<stdin>: ERROR: Syntax error \"_\"\n")
+	expectLexerError(t, "0_8", "<stdin>: ERROR: Syntax error \"_\"\n")
+	expectLexerError(t, "0_9", "<stdin>: ERROR: Syntax error \"_\"\n")
+	expectLexerError(t, "00_0", "<stdin>: ERROR: Syntax error \"_\"\n")
+	expectLexerError(t, "01_0", "<stdin>: ERROR: Syntax error \"_\"\n")
+	expectLexerError(t, "07_0", "<stdin>: ERROR: Syntax error \"_\"\n")
+	expectLexerError(t, "08_0", "<stdin>: ERROR: Syntax error \"_\"\n")
+	expectLexerError(t, "09_0", "<stdin>: ERROR: Syntax error \"_\"\n")
+	expectLexerError(t, "08_0.1", "<stdin>: ERROR: Syntax error \"_\"\n")
+	expectLexerError(t, "09_0.1", "<stdin>: ERROR: Syntax error \"_\"\n")
 
-	expectLexerError(t, "1__2", "<stdin>: error: Syntax error \"_\"\n")
-	expectLexerError(t, ".1__2", "<stdin>: error: Syntax error \"_\"\n")
-	expectLexerError(t, "1e2__3", "<stdin>: error: Syntax error \"_\"\n")
-	expectLexerError(t, "0b1__0", "<stdin>: error: Syntax error \"_\"\n")
-	expectLexerError(t, "0B1__0", "<stdin>: error: Syntax error \"_\"\n")
-	expectLexerError(t, "0o1__2", "<stdin>: error: Syntax error \"_\"\n")
-	expectLexerError(t, "0O1__2", "<stdin>: error: Syntax error \"_\"\n")
-	expectLexerError(t, "0x1__2", "<stdin>: error: Syntax error \"_\"\n")
-	expectLexerError(t, "0X1__2", "<stdin>: error: Syntax error \"_\"\n")
+	expectLexerError(t, "1__2", "<stdin>: ERROR: Syntax error \"_\"\n")
+	expectLexerError(t, ".1__2", "<stdin>: ERROR: Syntax error \"_\"\n")
+	expectLexerError(t, "1e2__3", "<stdin>: ERROR: Syntax error \"_\"\n")
+	expectLexerError(t, "0b1__0", "<stdin>: ERROR: Syntax error \"_\"\n")
+	expectLexerError(t, "0B1__0", "<stdin>: ERROR: Syntax error \"_\"\n")
+	expectLexerError(t, "0o1__2", "<stdin>: ERROR: Syntax error \"_\"\n")
+	expectLexerError(t, "0O1__2", "<stdin>: ERROR: Syntax error \"_\"\n")
+	expectLexerError(t, "0x1__2", "<stdin>: ERROR: Syntax error \"_\"\n")
+	expectLexerError(t, "0X1__2", "<stdin>: ERROR: Syntax error \"_\"\n")
 
-	expectLexerError(t, "1_", "<stdin>: error: Syntax error \"_\"\n")
-	expectLexerError(t, "1._", "<stdin>: error: Syntax error \"_\"\n")
-	expectLexerError(t, "1_.", "<stdin>: error: Syntax error \"_\"\n")
-	expectLexerError(t, ".1_", "<stdin>: error: Syntax error \"_\"\n")
-	expectLexerError(t, "1e_", "<stdin>: error: Syntax error \"_\"\n")
-	expectLexerError(t, "1e1_", "<stdin>: error: Syntax error \"_\"\n")
-	expectLexerError(t, "1_e1", "<stdin>: error: Syntax error \"_\"\n")
-	expectLexerError(t, ".1_e1", "<stdin>: error: Syntax error \"_\"\n")
-	expectLexerError(t, "1._2", "<stdin>: error: Syntax error \"_\"\n")
-	expectLexerError(t, "1_.2", "<stdin>: error: Syntax error \"_\"\n")
-	expectLexerError(t, "0b_1", "<stdin>: error: Syntax error \"_\"\n")
-	expectLexerError(t, "0B_1", "<stdin>: error: Syntax error \"_\"\n")
-	expectLexerError(t, "0o_1", "<stdin>: error: Syntax error \"_\"\n")
-	expectLexerError(t, "0O_1", "<stdin>: error: Syntax error \"_\"\n")
-	expectLexerError(t, "0x_1", "<stdin>: error: Syntax error \"_\"\n")
-	expectLexerError(t, "0X_1", "<stdin>: error: Syntax error \"_\"\n")
-	expectLexerError(t, "0b1_", "<stdin>: error: Syntax error \"_\"\n")
-	expectLexerError(t, "0B1_", "<stdin>: error: Syntax error \"_\"\n")
-	expectLexerError(t, "0o1_", "<stdin>: error: Syntax error \"_\"\n")
-	expectLexerError(t, "0O1_", "<stdin>: error: Syntax error \"_\"\n")
-	expectLexerError(t, "0x1_", "<stdin>: error: Syntax error \"_\"\n")
-	expectLexerError(t, "0X1_", "<stdin>: error: Syntax error \"_\"\n")
+	expectLexerError(t, "1_", "<stdin>: ERROR: Syntax error \"_\"\n")
+	expectLexerError(t, "1._", "<stdin>: ERROR: Syntax error \"_\"\n")
+	expectLexerError(t, "1_.", "<stdin>: ERROR: Syntax error \"_\"\n")
+	expectLexerError(t, ".1_", "<stdin>: ERROR: Syntax error \"_\"\n")
+	expectLexerError(t, "1e_", "<stdin>: ERROR: Syntax error \"_\"\n")
+	expectLexerError(t, "1e1_", "<stdin>: ERROR: Syntax error \"_\"\n")
+	expectLexerError(t, "1_e1", "<stdin>: ERROR: Syntax error \"_\"\n")
+	expectLexerError(t, ".1_e1", "<stdin>: ERROR: Syntax error \"_\"\n")
+	expectLexerError(t, "1._2", "<stdin>: ERROR: Syntax error \"_\"\n")
+	expectLexerError(t, "1_.2", "<stdin>: ERROR: Syntax error \"_\"\n")
+	expectLexerError(t, "0b_1", "<stdin>: ERROR: Syntax error \"_\"\n")
+	expectLexerError(t, "0B_1", "<stdin>: ERROR: Syntax error \"_\"\n")
+	expectLexerError(t, "0o_1", "<stdin>: ERROR: Syntax error \"_\"\n")
+	expectLexerError(t, "0O_1", "<stdin>: ERROR: Syntax error \"_\"\n")
+	expectLexerError(t, "0x_1", "<stdin>: ERROR: Syntax error \"_\"\n")
+	expectLexerError(t, "0X_1", "<stdin>: ERROR: Syntax error \"_\"\n")
+	expectLexerError(t, "0b1_", "<stdin>: ERROR: Syntax error \"_\"\n")
+	expectLexerError(t, "0B1_", "<stdin>: ERROR: Syntax error \"_\"\n")
+	expectLexerError(t, "0o1_", "<stdin>: ERROR: Syntax error \"_\"\n")
+	expectLexerError(t, "0O1_", "<stdin>: ERROR: Syntax error \"_\"\n")
+	expectLexerError(t, "0x1_", "<stdin>: ERROR: Syntax error \"_\"\n")
+	expectLexerError(t, "0X1_", "<stdin>: ERROR: Syntax error \"_\"\n")
 }
 
 func expectBigInteger(t *testing.T, contents string, expected string) {
@@ -386,13 +386,13 @@ func TestBigIntegerLiteral(t *testing.T) {
 	expectBigInteger(t, "0o1_2_3n", "0o123")
 	expectBigInteger(t, "0x1_2_3n", "0x123")
 
-	expectLexerError(t, "1e2n", "<stdin>: error: Syntax error \"n\"\n")
-	expectLexerError(t, "1.0n", "<stdin>: error: Syntax error \"n\"\n")
-	expectLexerError(t, ".1n", "<stdin>: error: Syntax error \"n\"\n")
-	expectLexerError(t, "000n", "<stdin>: error: Syntax error \"n\"\n")
-	expectLexerError(t, "0123n", "<stdin>: error: Syntax error \"n\"\n")
-	expectLexerError(t, "089n", "<stdin>: error: Syntax error \"n\"\n")
-	expectLexerError(t, "0_1n", "<stdin>: error: Syntax error \"_\"\n")
+	expectLexerError(t, "1e2n", "<stdin>: ERROR: Syntax error \"n\"\n")
+	expectLexerError(t, "1.0n", "<stdin>: ERROR: Syntax error \"n\"\n")
+	expectLexerError(t, ".1n", "<stdin>: ERROR: Syntax error \"n\"\n")
+	expectLexerError(t, "000n", "<stdin>: ERROR: Syntax error \"n\"\n")
+	expectLexerError(t, "0123n", "<stdin>: ERROR: Syntax error \"n\"\n")
+	expectLexerError(t, "089n", "<stdin>: ERROR: Syntax error \"n\"\n")
+	expectLexerError(t, "0_1n", "<stdin>: ERROR: Syntax error \"_\"\n")
 }
 
 func expectString(t *testing.T, contents string, expected string) {
@@ -500,14 +500,14 @@ func TestStringLiteral(t *testing.T) {
 
 	expectString(t, "'\\u{100000}'", "\U00100000")
 	expectString(t, "'\\u{10FFFF}'", "\U0010FFFF")
-	expectLexerErrorString(t, "'\\u{110000}'", "<stdin>: error: Unicode escape sequence is out of range\n")
-	expectLexerErrorString(t, "'\\u{FFFFFFFF}'", "<stdin>: error: Unicode escape sequence is out of range\n")
+	expectLexerErrorString(t, "'\\u{110000}'", "<stdin>: ERROR: Unicode escape sequence is out of range\n")
+	expectLexerErrorString(t, "'\\u{FFFFFFFF}'", "<stdin>: ERROR: Unicode escape sequence is out of range\n")
 
 	// Line continuation
-	expectLexerErrorString(t, "'\n'", "<stdin>: error: Unterminated string literal\n")
-	expectLexerErrorString(t, "'\r'", "<stdin>: error: Unterminated string literal\n")
-	expectLexerErrorString(t, "\"\n\"", "<stdin>: error: Unterminated string literal\n")
-	expectLexerErrorString(t, "\"\r\"", "<stdin>: error: Unterminated string literal\n")
+	expectLexerErrorString(t, "'\n'", "<stdin>: ERROR: Unterminated string literal\n")
+	expectLexerErrorString(t, "'\r'", "<stdin>: ERROR: Unterminated string literal\n")
+	expectLexerErrorString(t, "\"\n\"", "<stdin>: ERROR: Unterminated string literal\n")
+	expectLexerErrorString(t, "\"\r\"", "<stdin>: ERROR: Unterminated string literal\n")
 
 	expectString(t, "'\u2028'", "\u2028")
 	expectString(t, "'\u2029'", "\u2029")
@@ -519,24 +519,24 @@ func TestStringLiteral(t *testing.T) {
 	expectString(t, "'1\\\r\n2'", "12")
 	expectString(t, "'1\\\u20282'", "12")
 	expectString(t, "'1\\\u20292'", "12")
-	expectLexerErrorString(t, "'1\\\n\r2'", "<stdin>: error: Unterminated string literal\n")
+	expectLexerErrorString(t, "'1\\\n\r2'", "<stdin>: ERROR: Unterminated string literal\n")
 
-	expectLexerErrorString(t, "\"'", "<stdin>: error: Unterminated string literal\n")
-	expectLexerErrorString(t, "'\"", "<stdin>: error: Unterminated string literal\n")
-	expectLexerErrorString(t, "'\\", "<stdin>: error: Unterminated string literal\n")
-	expectLexerErrorString(t, "'\\'", "<stdin>: error: Unterminated string literal\n")
+	expectLexerErrorString(t, "\"'", "<stdin>: ERROR: Unterminated string literal\n")
+	expectLexerErrorString(t, "'\"", "<stdin>: ERROR: Unterminated string literal\n")
+	expectLexerErrorString(t, "'\\", "<stdin>: ERROR: Unterminated string literal\n")
+	expectLexerErrorString(t, "'\\'", "<stdin>: ERROR: Unterminated string literal\n")
 
-	expectLexerErrorString(t, "'\\x", "<stdin>: error: Unterminated string literal\n")
-	expectLexerErrorString(t, "'\\x'", "<stdin>: error: Syntax error \"'\"\n")
-	expectLexerErrorString(t, "'\\xG'", "<stdin>: error: Syntax error \"G\"\n")
-	expectLexerErrorString(t, "'\\xF'", "<stdin>: error: Syntax error \"'\"\n")
-	expectLexerErrorString(t, "'\\xFG'", "<stdin>: error: Syntax error \"G\"\n")
+	expectLexerErrorString(t, "'\\x", "<stdin>: ERROR: Unterminated string literal\n")
+	expectLexerErrorString(t, "'\\x'", "<stdin>: ERROR: Syntax error \"'\"\n")
+	expectLexerErrorString(t, "'\\xG'", "<stdin>: ERROR: Syntax error \"G\"\n")
+	expectLexerErrorString(t, "'\\xF'", "<stdin>: ERROR: Syntax error \"'\"\n")
+	expectLexerErrorString(t, "'\\xFG'", "<stdin>: ERROR: Syntax error \"G\"\n")
 
-	expectLexerErrorString(t, "'\\u", "<stdin>: error: Unterminated string literal\n")
-	expectLexerErrorString(t, "'\\u'", "<stdin>: error: Syntax error \"'\"\n")
-	expectLexerErrorString(t, "'\\u0'", "<stdin>: error: Syntax error \"'\"\n")
-	expectLexerErrorString(t, "'\\u00'", "<stdin>: error: Syntax error \"'\"\n")
-	expectLexerErrorString(t, "'\\u000'", "<stdin>: error: Syntax error \"'\"\n")
+	expectLexerErrorString(t, "'\\u", "<stdin>: ERROR: Unterminated string literal\n")
+	expectLexerErrorString(t, "'\\u'", "<stdin>: ERROR: Syntax error \"'\"\n")
+	expectLexerErrorString(t, "'\\u0'", "<stdin>: ERROR: Syntax error \"'\"\n")
+	expectLexerErrorString(t, "'\\u00'", "<stdin>: ERROR: Syntax error \"'\"\n")
+	expectLexerErrorString(t, "'\\u000'", "<stdin>: ERROR: Syntax error \"'\"\n")
 }
 
 func TestTokens(t *testing.T) {
