@@ -504,7 +504,7 @@ func TestLowerOptionalChain(t *testing.T) {
 
 	expectPrintedTarget(t, 2019, "null?.x", "void 0;\n")
 	expectPrintedTarget(t, 2019, "null?.[x]", "void 0;\n")
-	expectPrintedTarget(t, 2019, "null?.(x)", "void 0;\n")
+	expectPrintedTarget(t, 2019, "null?.(x)", "")
 
 	expectPrintedTarget(t, 2019, "delete null?.x", "true;\n")
 	expectPrintedTarget(t, 2019, "delete null?.[x]", "true;\n")
@@ -512,7 +512,7 @@ func TestLowerOptionalChain(t *testing.T) {
 
 	expectPrintedTarget(t, 2019, "undefined?.x", "void 0;\n")
 	expectPrintedTarget(t, 2019, "undefined?.[x]", "void 0;\n")
-	expectPrintedTarget(t, 2019, "undefined?.(x)", "void 0;\n")
+	expectPrintedTarget(t, 2019, "undefined?.(x)", "")
 
 	expectPrintedTarget(t, 2019, "delete undefined?.x", "true;\n")
 	expectPrintedTarget(t, 2019, "delete undefined?.[x]", "true;\n")
@@ -532,11 +532,11 @@ func TestLowerOptionalChain(t *testing.T) {
 
 	expectPrintedTarget(t, 2020, "null?.x", "void 0;\n")
 	expectPrintedTarget(t, 2020, "null?.[x]", "void 0;\n")
-	expectPrintedTarget(t, 2020, "null?.(x)", "void 0;\n")
+	expectPrintedTarget(t, 2020, "null?.(x)", "")
 
 	expectPrintedTarget(t, 2020, "undefined?.x", "void 0;\n")
 	expectPrintedTarget(t, 2020, "undefined?.[x]", "void 0;\n")
-	expectPrintedTarget(t, 2020, "undefined?.(x)", "void 0;\n")
+	expectPrintedTarget(t, 2020, "undefined?.(x)", "")
 
 	expectPrintedTarget(t, 2020, "(foo(), null)?.x", "(foo(), null)?.x;\n")
 	expectPrintedTarget(t, 2020, "(foo(), null)?.[x]", "(foo(), null)?.[x];\n")
