@@ -213,6 +213,9 @@ func (p *printer) printUnquotedUTF16(text []uint16, quote rune) {
 		case '\v':
 			js = append(js, "\\v"...)
 
+		case '\x1B':
+			js = append(js, "\\x1B"...)
+
 		case '\\':
 			js = append(js, "\\\\"...)
 
@@ -432,24 +435,25 @@ func (p *printer) printJSXTag(tagOrNil js_ast.Expr) {
 
 type printer struct {
 	symbols                js_ast.SymbolMap
+	isUnbound              func(js_ast.Ref) bool
 	renamer                renamer.Renamer
 	importRecords          []ast.ImportRecord
-	options                Options
+	callTarget             js_ast.E
 	extractedLegalComments map[string]bool
-	needsSemicolon         bool
-	moduleType             js_ast.ModuleType
 	js                     []byte
+	options                Options
+	builder                sourcemap.ChunkBuilder
 	stmtStart              int
 	exportDefaultStart     int
 	arrowExprStart         int
 	forOfInitStart         int
-	prevOp                 js_ast.OpCode
 	prevOpEnd              int
 	prevNumEnd             int
 	prevRegExpEnd          int
-	callTarget             js_ast.E
 	intToBytesBuffer       [64]byte
-	builder                sourcemap.ChunkBuilder
+	needsSemicolon         bool
+	prevOp                 js_ast.OpCode
+	moduleType             js_ast.ModuleType
 }
 
 func (p *printer) print(text string) {
@@ -1118,7 +1122,7 @@ func (p *printer) printRequireOrImportExpr(
 
 			// Finish the call to "__toESM()"
 			if wrapWithToESM {
-				if p.moduleType == js_ast.ModuleESM {
+				if p.moduleType.IsESM() {
 					p.print(",")
 					p.printSpace()
 					p.print("1")
@@ -1144,7 +1148,7 @@ func (p *printer) printRequireOrImportExpr(
 				p.printSymbol(p.options.ToESMRef)
 				p.print("(")
 				defer func() {
-					if p.moduleType == js_ast.ModuleESM {
+					if p.moduleType.IsESM() {
 						p.print(",")
 						p.printSpace()
 						p.print("1")
@@ -1248,7 +1252,7 @@ func (p *printer) printRequireOrImportExpr(
 
 	// Finish the call to "__toESM()"
 	if wrapWithToESM {
-		if p.moduleType == js_ast.ModuleESM {
+		if p.moduleType.IsESM() {
 			p.print(",")
 			p.printSpace()
 			p.print("1")
@@ -1291,17 +1295,6 @@ func (p *printer) printDotThenSuffix() {
 	}
 }
 
-type printExprFlags uint8
-
-const (
-	forbidCall printExprFlags = 1 << iota
-	forbidIn
-	hasNonOptionalChainParent
-	exprResultIsUnused
-	isFollowedByOf
-	isInsideForAwait
-)
-
 func (p *printer) printUndefined(level js_ast.L) {
 	if level >= js_ast.LPrefix {
 		p.print("(void 0)")
@@ -1312,10 +1305,121 @@ func (p *printer) printUndefined(level js_ast.L) {
 	}
 }
 
-func (p *printer) printExpr(expr js_ast.Expr, level js_ast.L, flags printExprFlags) {
-	wasFollowedByOf := (flags & isFollowedByOf) != 0
-	flags &= ^isFollowedByOf
+// Call this before printing an expression to see if it turned out to be empty.
+// We use this to do inlining of empty functions at print time. It can't happen
+// during parse time because a) parse time only has two passes and we only know
+// if a function can be inlined at the end of the second pass (due to is-mutated
+// analysis) and b) we want to enable cross-module inlining of empty functions
+// which has to happen after linking.
+//
+// This function returns "nil" to indicate that the expression should be removed
+// completely.
+//
+// This function doesn't need to search everywhere inside the entire expression
+// for calls to inline. Calls are automatically inlined when printed. However,
+// the printer replaces the call with "undefined" since the result may still
+// be needed by the caller. If the caller knows that it doesn't need the result,
+// it should call this function first instead so we don't print "undefined".
+//
+// This is a separate function instead of trying to work this logic into the
+// printer because it's too late to eliminate the expression entirely when we're
+// in the printer. We may have already printed the leading indent, for example.
+func (p *printer) simplifyUnusedExpr(expr js_ast.Expr) js_ast.Expr {
+	switch e := expr.Data.(type) {
+	case *js_ast.EBinary:
+		// Calls to be inlined may be hidden inside a comma operator chain
+		if e.Op == js_ast.BinOpComma {
+			left := p.simplifyUnusedExpr(e.Left)
+			right := p.simplifyUnusedExpr(e.Right)
+			if left.Data != e.Left.Data || right.Data != e.Right.Data {
+				return js_ast.JoinWithComma(left, right)
+			}
+		}
 
+	case *js_ast.ECall:
+		var symbolFlags js_ast.SymbolFlags
+		switch target := e.Target.Data.(type) {
+		case *js_ast.EIdentifier:
+			symbolFlags = p.symbols.Get(target.Ref).Flags
+		case *js_ast.EImportIdentifier:
+			ref := js_ast.FollowSymbols(p.symbols, target.Ref)
+			symbolFlags = p.symbols.Get(ref).Flags
+		}
+
+		// Replace non-mutated empty functions with their arguments at print time
+		if (symbolFlags & (js_ast.IsEmptyFunction | js_ast.CouldPotentiallyBeMutated)) == js_ast.IsEmptyFunction {
+			var replacement js_ast.Expr
+			for _, arg := range e.Args {
+				replacement = js_ast.JoinWithComma(replacement, js_ast.SimplifyUnusedExpr(p.simplifyUnusedExpr(arg), p.isUnbound))
+			}
+			return replacement // Don't add "undefined" here because the result isn't used
+		}
+
+		// Inline non-mutated identity functions at print time
+		if (symbolFlags&(js_ast.IsIdentityFunction|js_ast.CouldPotentiallyBeMutated)) == js_ast.IsIdentityFunction && len(e.Args) == 1 {
+			return js_ast.SimplifyUnusedExpr(p.simplifyUnusedExpr(e.Args[0]), p.isUnbound)
+		}
+	}
+
+	return expr
+}
+
+// This assumes the original expression was some form of indirect value, such
+// as a value returned from a function call or the result of a comma operator.
+// In this case, there is no special behavior with the "delete" operator or
+// with function calls. If we substitute this indirect value for another value
+// due to inlining, we have to make sure we don't accidentally introduce special
+// behavior.
+func (p *printer) guardAgainstBehaviorChangeDueToSubstitution(expr js_ast.Expr, flags printExprFlags) js_ast.Expr {
+	wrap := false
+
+	if (flags & isDeleteTarget) != 0 {
+		// "delete id(x)" must not become "delete x"
+		// "delete (empty(), x)" must not become "delete x"
+		if binary, ok := expr.Data.(*js_ast.EBinary); !ok || binary.Op != js_ast.BinOpComma {
+			wrap = true
+		}
+	} else if (flags & isCallTargetOrTemplateTag) != 0 {
+		// "id(x.y)()" must not become "x.y()"
+		// "id(x.y)``" must not become "x.y``"
+		// "(empty(), x.y)()" must not become "x.y()"
+		// "(empty(), eval)()" must not become "eval()"
+		switch expr.Data.(type) {
+		case *js_ast.EDot, *js_ast.EIndex:
+			wrap = true
+		case *js_ast.EIdentifier:
+			if p.isUnboundEvalIdentifier(expr) {
+				wrap = true
+			}
+		}
+	}
+
+	if wrap {
+		expr.Data = &js_ast.EBinary{
+			Op:    js_ast.BinOpComma,
+			Left:  js_ast.Expr{Loc: expr.Loc, Data: &js_ast.ENumber{Value: 0}},
+			Right: expr,
+		}
+	}
+
+	return expr
+}
+
+type printExprFlags uint16
+
+const (
+	forbidCall printExprFlags = 1 << iota
+	forbidIn
+	hasNonOptionalChainParent
+	exprResultIsUnused
+	didAlreadySimplifyUnusedExprs
+	isFollowedByOf
+	isInsideForAwait
+	isDeleteTarget
+	isCallTargetOrTemplateTag
+)
+
+func (p *printer) printExpr(expr js_ast.Expr, level js_ast.L, flags printExprFlags) {
 	p.addSourceMapping(expr.Loc)
 
 	switch e := expr.Data.(type) {
@@ -1481,6 +1585,40 @@ func (p *printer) printExpr(expr js_ast.Expr, level js_ast.L, flags printExprFla
 		}
 
 	case *js_ast.ECall:
+		if p.options.MangleSyntax {
+			var symbolFlags js_ast.SymbolFlags
+			switch target := e.Target.Data.(type) {
+			case *js_ast.EIdentifier:
+				symbolFlags = p.symbols.Get(target.Ref).Flags
+			case *js_ast.EImportIdentifier:
+				ref := js_ast.FollowSymbols(p.symbols, target.Ref)
+				symbolFlags = p.symbols.Get(ref).Flags
+			}
+
+			// Replace non-mutated empty functions with their arguments at print time
+			if (symbolFlags & (js_ast.IsEmptyFunction | js_ast.CouldPotentiallyBeMutated)) == js_ast.IsEmptyFunction {
+				var replacement js_ast.Expr
+				for _, arg := range e.Args {
+					replacement = js_ast.JoinWithComma(replacement, js_ast.SimplifyUnusedExpr(arg, p.isUnbound))
+				}
+				if replacement.Data == nil || (flags&exprResultIsUnused) == 0 {
+					replacement = js_ast.JoinWithComma(replacement, js_ast.Expr{Loc: expr.Loc, Data: js_ast.EUndefinedShared})
+				}
+				p.printExpr(p.guardAgainstBehaviorChangeDueToSubstitution(replacement, flags), level, flags)
+				break
+			}
+
+			// Inline non-mutated identity functions at print time
+			if (symbolFlags&(js_ast.IsIdentityFunction|js_ast.CouldPotentiallyBeMutated)) == js_ast.IsIdentityFunction && len(e.Args) == 1 {
+				arg := e.Args[0]
+				if (flags & exprResultIsUnused) != 0 {
+					arg = js_ast.SimplifyUnusedExpr(arg, p.isUnbound)
+				}
+				p.printExpr(p.guardAgainstBehaviorChangeDueToSubstitution(arg, flags), level, flags)
+				break
+			}
+		}
+
 		wrap := level >= js_ast.LNew || (flags&forbidCall) != 0
 		var targetFlags printExprFlags
 		if e.OptionalChain == js_ast.OptionalChainNone {
@@ -1514,10 +1652,10 @@ func (p *printer) printExpr(expr js_ast.Expr, level js_ast.L, flags printExprFla
 			} else {
 				p.print("(0, ")
 			}
-			p.printExpr(e.Target, js_ast.LPostfix, 0)
+			p.printExpr(e.Target, js_ast.LPostfix, isCallTargetOrTemplateTag)
 			p.print(")")
 		} else {
-			p.printExpr(e.Target, js_ast.LPostfix, targetFlags)
+			p.printExpr(e.Target, js_ast.LPostfix, isCallTargetOrTemplateTag|targetFlags)
 		}
 
 		if e.OptionalChain == js_ast.OptionalChainStart {
@@ -1627,7 +1765,7 @@ func (p *printer) printExpr(expr js_ast.Expr, level js_ast.L, flags printExprFla
 			}
 			flags &= ^hasNonOptionalChainParent
 		}
-		p.printExpr(e.Target, js_ast.LPostfix, flags)
+		p.printExpr(e.Target, js_ast.LPostfix, flags&(forbidCall|hasNonOptionalChainParent))
 		if p.canPrintIdentifier(e.Name) {
 			if e.OptionalChain != js_ast.OptionalChainStart && p.prevNumEnd == len(p.js) {
 				// "1.toString" is a syntax error, so print "1 .toString" instead
@@ -1689,7 +1827,7 @@ func (p *printer) printExpr(expr js_ast.Expr, level js_ast.L, flags printExprFla
 			}
 			flags &= ^hasNonOptionalChainParent
 		}
-		p.printExpr(e.Target, js_ast.LPostfix, flags)
+		p.printExpr(e.Target, js_ast.LPostfix, flags&(forbidCall|hasNonOptionalChainParent))
 		if e.OptionalChain == js_ast.OptionalChainStart {
 			p.print("?.")
 		}
@@ -1916,10 +2054,10 @@ func (p *printer) printExpr(expr js_ast.Expr, level js_ast.L, flags printExprFla
 			// Optional chains are forbidden in template tags
 			if js_ast.IsOptionalChain(e.TagOrNil) {
 				p.print("(")
-				p.printExpr(e.TagOrNil, js_ast.LLowest, 0)
+				p.printExpr(e.TagOrNil, js_ast.LLowest, isCallTargetOrTemplateTag)
 				p.print(")")
 			} else {
-				p.printExpr(e.TagOrNil, js_ast.LPostfix, 0)
+				p.printExpr(e.TagOrNil, js_ast.LPostfix, isCallTargetOrTemplateTag)
 			}
 		}
 		p.print("`")
@@ -1975,7 +2113,7 @@ func (p *printer) printExpr(expr js_ast.Expr, level js_ast.L, flags printExprFla
 	case *js_ast.EIdentifier:
 		name := p.renamer.NameForSymbol(e.Ref)
 		wrap := len(p.js) == p.forOfInitStart && (name == "let" ||
-			(wasFollowedByOf && (flags&isInsideForAwait) == 0 && name == "async"))
+			((flags&isFollowedByOf) != 0 && (flags&isInsideForAwait) == 0 && name == "async"))
 
 		if wrap {
 			p.print("(")
@@ -2083,7 +2221,11 @@ func (p *printer) printExpr(expr js_ast.Expr, level js_ast.L, flags printExprFla
 		}
 
 		if e.Op.IsPrefix() {
-			p.printExpr(e.Value, js_ast.LPrefix-1, 0)
+			var valueFlags printExprFlags
+			if e.Op == js_ast.UnOpDelete {
+				valueFlags |= isDeleteTarget
+			}
+			p.printExpr(e.Value, js_ast.LPrefix-1, valueFlags)
 		}
 
 		if wrap {
@@ -2091,6 +2233,27 @@ func (p *printer) printExpr(expr js_ast.Expr, level js_ast.L, flags printExprFla
 		}
 
 	case *js_ast.EBinary:
+		// If this is a comma operator then either the result is unused (and we
+		// should have already simplified unused expressions), or the result is used
+		// (and we can still simplify unused expressions inside the left operand)
+		if e.Op == js_ast.BinOpComma {
+			if (flags & didAlreadySimplifyUnusedExprs) == 0 {
+				left := p.simplifyUnusedExpr(e.Left)
+				right := e.Right
+				if (flags & exprResultIsUnused) != 0 {
+					right = p.simplifyUnusedExpr(right)
+				}
+				if left.Data != e.Left.Data || right.Data != e.Right.Data {
+					// Pass a flag so we don't needlessly re-simplify the same expression
+					p.printExpr(p.guardAgainstBehaviorChangeDueToSubstitution(js_ast.JoinWithComma(left, right), flags), level, flags|didAlreadySimplifyUnusedExprs)
+					break
+				}
+			} else {
+				// Pass a flag so we don't needlessly re-simplify the same expression
+				flags |= didAlreadySimplifyUnusedExprs
+			}
+		}
+
 		entry := js_ast.OpTable[e.Op]
 		wrap := level >= entry.Level || (e.Op == js_ast.BinOpIn && (flags&forbidIn) != 0)
 
@@ -2149,6 +2312,9 @@ func (p *printer) printExpr(expr js_ast.Expr, level js_ast.L, flags printExprFla
 		// Special-case "#foo in bar"
 		if private, ok := e.Left.Data.(*js_ast.EPrivateIdentifier); ok && e.Op == js_ast.BinOpIn {
 			p.printSymbol(private.Ref)
+		} else if e.Op == js_ast.BinOpComma {
+			// The result of the left operand of the comma operator is unused
+			p.printExpr(e.Left, leftLevel, (flags&forbidIn)|exprResultIsUnused)
 		} else {
 			p.printExpr(e.Left, leftLevel, flags&forbidIn)
 		}
@@ -2169,7 +2335,12 @@ func (p *printer) printExpr(expr js_ast.Expr, level js_ast.L, flags printExprFla
 
 		p.printSpace()
 
-		p.printExpr(e.Right, rightLevel, flags&forbidIn)
+		if e.Op == js_ast.BinOpComma {
+			// The result of the right operand of the comma operator is unused if the caller doesn't use it
+			p.printExpr(e.Right, rightLevel, flags&(forbidIn|exprResultIsUnused))
+		} else {
+			p.printExpr(e.Right, rightLevel, flags&forbidIn)
+		}
 
 		if wrap {
 			p.print(")")
@@ -2410,7 +2581,7 @@ func (p *printer) printBody(body js_ast.Stmt) {
 	} else {
 		p.printNewline()
 		p.options.Indent++
-		p.printStmt(body)
+		p.printStmt(body, 0)
 		p.options.Indent--
 	}
 }
@@ -2423,7 +2594,7 @@ func (p *printer) printBlock(loc logger.Loc, stmts []js_ast.Stmt) {
 	p.options.Indent++
 	for _, stmt := range stmts {
 		p.printSemicolonIfNeeded()
-		p.printStmt(stmt)
+		p.printStmt(stmt, canOmitStatement)
 	}
 	p.options.Indent--
 	p.needsSemicolon = false
@@ -2485,7 +2656,7 @@ func (p *printer) printIf(s *js_ast.SIf) {
 		p.printNewline()
 
 		p.options.Indent++
-		p.printStmt(s.Yes)
+		p.printStmt(s.Yes, canOmitStatement)
 		p.options.Indent--
 		p.needsSemicolon = false
 
@@ -2500,7 +2671,7 @@ func (p *printer) printIf(s *js_ast.SIf) {
 	} else {
 		p.printNewline()
 		p.options.Indent++
-		p.printStmt(s.Yes)
+		p.printStmt(s.Yes, 0)
 		p.options.Indent--
 
 		if s.NoOrNil.Data != nil {
@@ -2522,7 +2693,7 @@ func (p *printer) printIf(s *js_ast.SIf) {
 		} else {
 			p.printNewline()
 			p.options.Indent++
-			p.printStmt(s.NoOrNil)
+			p.printStmt(s.NoOrNil, 0)
 			p.options.Indent--
 		}
 	}
@@ -2620,7 +2791,13 @@ func (p *printer) printImportAssertionsClause(assertions []ast.AssertEntry) {
 	p.print("}")
 }
 
-func (p *printer) printStmt(stmt js_ast.Stmt) {
+type printStmtFlags uint8
+
+const (
+	canOmitStatement printStmtFlags = 1 << iota
+)
+
+func (p *printer) printStmt(stmt js_ast.Stmt, flags printStmtFlags) {
 	p.addSourceMapping(stmt.Loc)
 
 	switch s := stmt.Data.(type) {
@@ -2858,7 +3035,7 @@ func (p *printer) printStmt(stmt js_ast.Stmt) {
 		} else {
 			p.printNewline()
 			p.options.Indent++
-			p.printStmt(s.Body)
+			p.printStmt(s.Body, 0)
 			p.printSemicolonIfNeeded()
 			p.options.Indent--
 			p.printIndent()
@@ -2964,13 +3141,30 @@ func (p *printer) printStmt(stmt js_ast.Stmt) {
 		p.printNewline()
 
 	case *js_ast.SFor:
+		init := s.InitOrNil
+		update := s.UpdateOrNil
+
+		// Omit calls to empty functions from the output completely
+		if p.options.MangleSyntax {
+			if expr, ok := init.Data.(*js_ast.SExpr); ok {
+				if value := p.simplifyUnusedExpr(expr.Value); value.Data == nil {
+					init.Data = nil
+				} else if value.Data != expr.Value.Data {
+					init.Data = &js_ast.SExpr{Value: value}
+				}
+			}
+			if update.Data != nil {
+				update = p.simplifyUnusedExpr(update)
+			}
+		}
+
 		p.printIndent()
 		p.printSpaceBeforeIdentifier()
 		p.print("for")
 		p.printSpace()
 		p.print("(")
-		if s.InitOrNil.Data != nil {
-			p.printForLoopInit(s.InitOrNil, forbidIn)
+		if init.Data != nil {
+			p.printForLoopInit(init, forbidIn)
 		}
 		p.print(";")
 		p.printSpace()
@@ -2979,8 +3173,8 @@ func (p *printer) printStmt(stmt js_ast.Stmt) {
 		}
 		p.print(";")
 		p.printSpace()
-		if s.UpdateOrNil.Data != nil {
-			p.printExpr(s.UpdateOrNil, js_ast.LLowest, 0)
+		if update.Data != nil {
+			p.printExpr(update, js_ast.LLowest, exprResultIsUnused)
 		}
 		p.print(")")
 		p.printBody(s.Body)
@@ -3024,7 +3218,7 @@ func (p *printer) printStmt(stmt js_ast.Stmt) {
 			p.options.Indent++
 			for _, stmt := range c.Body {
 				p.printSemicolonIfNeeded()
-				p.printStmt(stmt)
+				p.printStmt(stmt, canOmitStatement)
 			}
 			p.options.Indent--
 		}
@@ -3172,9 +3366,28 @@ func (p *printer) printStmt(stmt js_ast.Stmt) {
 		p.printSemicolonAfterStatement()
 
 	case *js_ast.SExpr:
+		value := s.Value
+
+		// Omit calls to empty functions from the output completely
+		if p.options.MangleSyntax {
+			value = p.simplifyUnusedExpr(value)
+			if value.Data == nil {
+				// If this statement is not in a block, then we still need to emit something
+				if (flags & canOmitStatement) == 0 {
+					// "if (x) empty();" => "if (x) ;"
+					p.printIndent()
+					p.print(";")
+					p.printNewline()
+				} else {
+					// "if (x) { empty(); }" => "if (x) {}"
+				}
+				break
+			}
+		}
+
 		p.printIndent()
 		p.stmtStart = len(p.js)
-		p.printExpr(s.Value, js_ast.LLowest, exprResultIsUnused)
+		p.printExpr(value, js_ast.LLowest, exprResultIsUnused)
 		p.printSemicolonAfterStatement()
 
 	default:
@@ -3183,29 +3396,30 @@ func (p *printer) printStmt(stmt js_ast.Stmt) {
 }
 
 type Options struct {
-	OutputFormat                 config.Format
-	RemoveWhitespace             bool
-	MangleSyntax                 bool
-	ASCIIOnly                    bool
-	LegalComments                config.LegalComments
-	AddSourceMappings            bool
-	Indent                       int
-	ToCommonJSRef                js_ast.Ref
-	ToESMRef                     js_ast.Ref
-	RuntimeRequireRef            js_ast.Ref
-	UnsupportedFeatures          compat.JSFeature
 	RequireOrImportMetaForSource func(uint32) RequireOrImportMeta
 
 	// Cross-module inlining of TypeScript enums is actually done during printing
 	TSEnums map[js_ast.Ref]map[string]js_ast.TSEnumValue
 
+	// This will be present if the input file had a source map. In that case we
+	// want to map all the way back to the original input file(s).
+	InputSourceMap *sourcemap.SourceMap
+
 	// If we're writing out a source map, this table of line start indices lets
 	// us do binary search on to figure out what line a given AST node came from
 	LineOffsetTables []sourcemap.LineOffsetTable
 
-	// This will be present if the input file had a source map. In that case we
-	// want to map all the way back to the original input file(s).
-	InputSourceMap *sourcemap.SourceMap
+	ToCommonJSRef       js_ast.Ref
+	ToESMRef            js_ast.Ref
+	RuntimeRequireRef   js_ast.Ref
+	UnsupportedFeatures compat.JSFeature
+	Indent              int
+	OutputFormat        config.Format
+	RemoveWhitespace    bool
+	MangleSyntax        bool
+	ASCIIOnly           bool
+	LegalComments       config.LegalComments
+	AddSourceMappings   bool
 }
 
 type RequireOrImportMeta struct {
@@ -3218,14 +3432,13 @@ type RequireOrImportMeta struct {
 }
 
 type PrintResult struct {
-	JS []byte
+	JS                     []byte
+	ExtractedLegalComments map[string]bool
 
 	// This source map chunk just contains the VLQ-encoded offsets for the "JS"
 	// field above. It's not a full source map. The bundler will be joining many
 	// source map chunks together to form the final source map.
 	SourceMapChunk sourcemap.Chunk
-
-	ExtractedLegalComments map[string]bool
 }
 
 func Print(tree js_ast.AST, symbols js_ast.SymbolMap, r renamer.Renamer, options Options) PrintResult {
@@ -3234,7 +3447,7 @@ func Print(tree js_ast.AST, symbols js_ast.SymbolMap, r renamer.Renamer, options
 		renamer:            r,
 		importRecords:      tree.ImportRecords,
 		options:            options,
-		moduleType:         tree.ModuleType,
+		moduleType:         tree.ModuleTypeData.Type,
 		stmtStart:          -1,
 		exportDefaultStart: -1,
 		arrowExprStart:     -1,
@@ -3245,6 +3458,11 @@ func Print(tree js_ast.AST, symbols js_ast.SymbolMap, r renamer.Renamer, options
 		builder:            sourcemap.MakeChunkBuilder(options.InputSourceMap, options.LineOffsetTables),
 	}
 
+	p.isUnbound = func(ref js_ast.Ref) bool {
+		ref = js_ast.FollowSymbols(symbols, ref)
+		return symbols.Get(ref).Kind == js_ast.SymbolUnbound
+	}
+
 	// Add the top-level directive if present
 	if tree.Directive != "" {
 		p.printIndent()
@@ -3255,7 +3473,7 @@ func Print(tree js_ast.AST, symbols js_ast.SymbolMap, r renamer.Renamer, options
 
 	for _, part := range tree.Parts {
 		for _, stmt := range part.Stmts {
-			p.printStmt(stmt)
+			p.printStmt(stmt, canOmitStatement)
 			p.printSemicolonIfNeeded()
 		}
 	}
