@@ -16,9 +16,8 @@ import (
 )
 
 type packageJSON struct {
-	source     logger.Source
-	mainFields map[string]mainField
-	moduleType config.ModuleType
+	mainFields     map[string]mainField
+	moduleTypeData js_ast.ModuleTypeData
 
 	// Present if the "browser" field is present. This field is intended to be
 	// used by bundlers and lets you redirect the paths of certain 3rd-party
@@ -66,11 +65,13 @@ type packageJSON struct {
 
 	// This represents the "exports" field in this package.json file.
 	exportsMap *pjMap
+
+	source logger.Source
 }
 
 type mainField struct {
-	keyLoc  logger.Loc
 	relPath string
+	keyLoc  logger.Loc
 }
 
 type browserPathKind uint8
@@ -253,9 +254,17 @@ func (r resolverQuery) parsePackageJSON(inputPath string) *packageJSON {
 		if typeValue, ok := getString(typeJSON); ok {
 			switch typeValue {
 			case "commonjs":
-				packageJSON.moduleType = config.ModuleCommonJS
+				packageJSON.moduleTypeData = js_ast.ModuleTypeData{
+					Type:   js_ast.ModuleCommonJS_PackageJSON,
+					Source: &packageJSON.source,
+					Range:  jsonSource.RangeOfString(typeJSON.Loc),
+				}
 			case "module":
-				packageJSON.moduleType = config.ModuleESM
+				packageJSON.moduleTypeData = js_ast.ModuleTypeData{
+					Type:   js_ast.ModuleESM_PackageJSON,
+					Source: &packageJSON.source,
+					Range:  jsonSource.RangeOfString(typeJSON.Loc),
+				}
 			default:
 				r.log.AddWithNotes(logger.Warning, &tracker, jsonSource.RangeOfString(typeJSON.Loc),
 					fmt.Sprintf("%q is not a valid value for the \"type\" field", typeValue),
@@ -274,17 +283,17 @@ func (r resolverQuery) parsePackageJSON(inputPath string) *packageJSON {
 		mainFields = defaultMainFields[r.options.Platform]
 	}
 	for _, field := range mainFields {
-		if mainJSON, mainRange, ok := getProperty(json, field); ok {
+		if mainJSON, mainLoc, ok := getProperty(json, field); ok {
 			if main, ok := getString(mainJSON); ok && main != "" {
-				packageJSON.mainFields[field] = mainField{mainRange, main}
+				packageJSON.mainFields[field] = mainField{keyLoc: mainLoc, relPath: main}
 			}
 		}
 	}
 	for _, field := range mainFieldsForFailure {
 		if _, ok := packageJSON.mainFields[field]; !ok {
-			if mainJSON, mainRange, ok := getProperty(json, field); ok {
+			if mainJSON, mainLoc, ok := getProperty(json, field); ok {
 				if main, ok := getString(mainJSON); ok && main != "" {
-					packageJSON.mainFields[field] = mainField{mainRange, main}
+					packageJSON.mainFields[field] = mainField{keyLoc: mainLoc, relPath: main}
 				}
 			}
 		}
@@ -492,8 +501,8 @@ type pjEntry struct {
 
 type pjMapEntry struct {
 	key      string
-	keyRange logger.Range
 	value    pjEntry
+	keyRange logger.Range
 }
 
 // This type is just so we can use Go's native sort function
@@ -667,12 +676,12 @@ func (status pjStatus) isUndefined() bool {
 }
 
 type pjDebug struct {
-	// This is the range of the token to use for error messages
-	token logger.Range
-
 	// If the status is "pjStatusUndefinedNoConditionsMatch", this is the set of
 	// conditions that didn't match. This information is used for error messages.
 	unmatchedConditions []string
+
+	// This is the range of the token to use for error messages
+	token logger.Range
 }
 
 func (r resolverQuery) esmHandlePostConditions(
