@@ -1,5 +1,6 @@
 import * as types from "../shared/types";
 import * as common from "../shared/common";
+import * as ourselves from "./node"
 import { ESBUILD_BINARY_PATH, generateBinPath } from "./node-platform";
 
 import child_process = require('child_process');
@@ -254,6 +255,7 @@ let ensureServiceIsRunning = (): Service => {
     readFileSync: fs.readFileSync,
     isSync: false,
     isBrowser: false,
+    esbuild: ourselves,
   });
 
   const stdin: typeof child.stdin & { unref?(): void } = child.stdin;
@@ -349,6 +351,7 @@ let runServiceSync = (callback: (service: common.StreamService) => void): void =
     },
     isSync: true,
     isBrowser: false,
+    esbuild: ourselves,
   });
   callback(service);
   let stdout = child_process.execFileSync(command, args.concat(`--service=${ESBUILD_VERSION}`), {
