@@ -3,6 +3,7 @@ export type Format = 'iife' | 'cjs' | 'esm';
 export type Loader = 'js' | 'jsx' | 'ts' | 'tsx' | 'css' | 'json' | 'text' | 'base64' | 'file' | 'dataurl' | 'binary' | 'default';
 export type LogLevel = 'verbose' | 'debug' | 'info' | 'warning' | 'error' | 'silent';
 export type Charset = 'ascii' | 'utf8';
+export type Drop = 'console' | 'debugger';
 
 interface CommonOptions {
   /** Documentation: https://esbuild.github.io/api/#sourcemap */
@@ -21,6 +22,7 @@ interface CommonOptions {
   /** Documentation: https://esbuild.github.io/api/#target */
   target?: string | string[];
 
+  drop?: Drop[];
   /** Documentation: https://esbuild.github.io/api/#minify */
   minify?: boolean;
   /** Documentation: https://esbuild.github.io/api/#minify */
@@ -288,6 +290,7 @@ export interface PluginBuild {
 }
 
 export interface ResolveOptions {
+  pluginName?: string;
   importer?: string;
   namespace?: string;
   resolveDir?: string;
@@ -446,7 +449,9 @@ export interface AnalyzeMetafileOptions {
  * Documentation: https://esbuild.github.io/api/#build-api
  */
 export declare function build(options: BuildOptions & { write: false }): Promise<BuildResult & { outputFiles: OutputFile[] }>;
+export declare function build(options: BuildOptions & { incremental: true, metafile: true }): Promise<BuildIncremental & { metafile: Metafile }>;
 export declare function build(options: BuildOptions & { incremental: true }): Promise<BuildIncremental>;
+export declare function build(options: BuildOptions & { metafile: true }): Promise<BuildResult & { metafile: Metafile }>;
 export declare function build(options: BuildOptions): Promise<BuildResult>;
 
 /**
