@@ -96,6 +96,28 @@ func parseOptionsImpl(
 				transformOpts.MinifyIdentifiers = true
 			}
 
+		case strings.HasPrefix(arg, "--drop:"):
+			value := arg[len("--drop:"):]
+			switch value {
+			case "console":
+				if buildOpts != nil {
+					buildOpts.Drop |= api.DropConsole
+				} else {
+					transformOpts.Drop |= api.DropConsole
+				}
+			case "debugger":
+				if buildOpts != nil {
+					buildOpts.Drop |= api.DropDebugger
+				} else {
+					transformOpts.Drop |= api.DropDebugger
+				}
+			default:
+				return cli_helpers.MakeErrorWithNote(
+					fmt.Sprintf("Invalid value %q in %q", value, arg),
+					"Valid values are \"console\" or \"debugger\".",
+				), nil
+			}
+
 		case strings.HasPrefix(arg, "--legal-comments="):
 			value := arg[len("--legal-comments="):]
 			var legalComments api.LegalComments
@@ -601,49 +623,50 @@ func parseOptionsImpl(
 			}
 
 			equals := map[string]bool{
-				"legal-comments":     true,
-				"charset":            true,
-				"tree-shaking":       true,
-				"sourcemap":          true,
-				"source-root":        true,
-				"sources-content":    true,
-				"sourcefile":         true,
-				"resolve-extensions": true,
-				"main-fields":        true,
-				"conditions":         true,
-				"public-path":        true,
-				"global-name":        true,
-				"outfile":            true,
-				"outdir":             true,
-				"outbase":            true,
-				"tsconfig":           true,
-				"tsconfig-raw":       true,
-				"entry-names":        true,
-				"chunk-names":        true,
 				"asset-names":        true,
-				"loader":             true,
-				"target":             true,
-				"platform":           true,
+				"banner":             true,
+				"charset":            true,
+				"chunk-names":        true,
+				"color":              true,
+				"conditions":         true,
+				"entry-names":        true,
+				"footer":             true,
 				"format":             true,
-				"jsx":                true,
+				"global-name":        true,
 				"jsx-factory":        true,
 				"jsx-fragment":       true,
-				"banner":             true,
-				"footer":             true,
-				"log-limit":          true,
-				"color":              true,
+				"jsx":                true,
+				"legal-comments":     true,
+				"loader":             true,
 				"log-level":          true,
+				"log-limit":          true,
+				"main-fields":        true,
+				"outbase":            true,
+				"outdir":             true,
+				"outfile":            true,
+				"platform":           true,
+				"public-path":        true,
+				"resolve-extensions": true,
+				"source-root":        true,
+				"sourcefile":         true,
+				"sourcemap":          true,
+				"sources-content":    true,
+				"target":             true,
+				"tree-shaking":       true,
+				"tsconfig-raw":       true,
+				"tsconfig":           true,
 			}
 
 			colon := map[string]bool{
+				"banner":        true,
 				"define":        true,
-				"pure":          true,
+				"drop":          true,
+				"external":      true,
+				"footer":        true,
+				"inject":        true,
 				"loader":        true,
 				"out-extension": true,
-				"external":      true,
-				"inject":        true,
-				"banner":        true,
-				"footer":        true,
+				"pure":          true,
 			}
 
 			note := ""
