@@ -11,23 +11,76 @@ const esmMin = fs.readFileSync(path.join(__dirname, '..', '..', 'npm', 'esbuild-
 const wasm = fs.readFileSync(path.join(__dirname, '..', '..', 'npm', 'esbuild-wasm', 'esbuild.wasm'))
 
 // This is converted to a string and run inside the browser
-async function runAllTests({ esbuild, service }) {
+async function runAllTests({ esbuild }) {
+  function setupForProblemCSS(prefix) {
+    // https://github.com/tailwindlabs/tailwindcss/issues/2889
+    const original = `
+      /* Variant 1 */
+      .${prefix}-v1 { --a: ; --b: ; max-width: var(--a) var(--b); }
+      .${prefix}-a { --a: 1px; }
+      .${prefix}-b { --b: 2px; }
+
+      /* Variant 2 */
+      .${prefix}-v2 { max-width: var(--a, ) var(--b, ); }
+      .${prefix}-a { --a: 1px; }
+      .${prefix}-b { --b: 2px; }
+    `
+    const style = document.createElement('style')
+    const test1a = document.createElement('div')
+    const test1b = document.createElement('div')
+    const test2a = document.createElement('div')
+    const test2b = document.createElement('div')
+    document.head.appendChild(style)
+    document.body.appendChild(test1a)
+    document.body.appendChild(test1b)
+    document.body.appendChild(test2a)
+    document.body.appendChild(test2b)
+    test1a.className = `${prefix}-v1 ${prefix}-a`
+    test1b.className = `${prefix}-v1 ${prefix}-b`
+    test2a.className = `${prefix}-v2 ${prefix}-a`
+    test2b.className = `${prefix}-v2 ${prefix}-b`
+    return [original, css => {
+      style.textContent = css
+      assertStrictEqual(getComputedStyle(test1a).maxWidth, `1px`)
+      assertStrictEqual(getComputedStyle(test1b).maxWidth, `2px`)
+      assertStrictEqual(getComputedStyle(test2a).maxWidth, `1px`)
+      assertStrictEqual(getComputedStyle(test2b).maxWidth, `2px`)
+    }]
+  }
+
   const tests = {
     async transformJS() {
-      const { code } = await service.transform('1+2')
+      const { code } = await esbuild.transform('1+2')
       assertStrictEqual(code, '1 + 2;\n')
     },
 
     async transformTS() {
-      const { code } = await service.transform('1 as any + <any>2', { loader: 'ts' })
+      const { code } = await esbuild.transform('1 as any + <any>2', { loader: 'ts' })
       assertStrictEqual(code, '1 + 2;\n')
     },
 
     async transformCSS() {
-      const { code } = await service.transform('div { color: red }', { loader: 'css' })
+      const { code } = await esbuild.transform('div { color: red }', { loader: 'css' })
       assertStrictEqual(code, 'div {\n  color: red;\n}\n')
     },
 
+    async problemCSSOriginal() {
+      const [original, runAsserts] = setupForProblemCSS('original')
+      runAsserts(original)
+    },
+
+    async problemCSSPrettyPrinted() {
+      const [original, runAsserts] = setupForProblemCSS('pretty-print')
+      const { code: prettyPrinted } = await esbuild.transform(original, { loader: 'css' })
+      runAsserts(prettyPrinted)
+    },
+
+    async problemCSSMinified() {
+      const [original, runAsserts] = setupForProblemCSS('pretty-print')
+      const { code: minified } = await esbuild.transform(original, { loader: 'css', minify: true })
+      runAsserts(minified)
+    },
+
     async buildFib() {
       const fibonacciPlugin = {
         name: 'fib',
@@ -45,11 +98,11 @@ async function runAllTests({ esbuild, service }) {
           })
         },
       }
-      const result = await service.build({
+      const result = await esbuild.build({
         stdin: {
           contents: `
             import x from 'fib(10)'
-            return x
+            module.exports = x
           `,
         },
         format: 'cjs',
@@ -59,12 +112,13 @@ async function runAllTests({ esbuild, service }) {
       assertStrictEqual(result.outputFiles.length, 1)
       assertStrictEqual(result.outputFiles[0].path, '<stdout>')
       const code = result.outputFiles[0].text
-      const fib10 = new Function(code)()
-      assertStrictEqual(fib10, 55)
+      const answer = {}
+      new Function('module', code)(answer)
+      assertStrictEqual(answer.exports, 55)
     },
 
     async buildRelativeIssue693() {
-      const result = await service.build({
+      const result = await esbuild.build({
         stdin: {
           contents: `const x=1`,
         },
@@ -77,15 +131,7 @@ async function runAllTests({ esbuild, service }) {
     },
 
     async serve() {
-      expectThrownError(service.serve, 'The "serve" API only works in node')
-    },
-
-    async esbuildBuild() {
-      expectThrownError(esbuild.build, 'The "build" API only works in node')
-    },
-
-    async esbuildTransform() {
-      expectThrownError(esbuild.transform, 'The "transform" API only works in node')
+      expectThrownError(esbuild.serve, 'The "serve" API only works in node')
     },
 
     async esbuildBuildSync() {
@@ -136,11 +182,11 @@ for (let format of ['iife', 'esm']) {
     for (let async of [false, true]) {
       let code = `
         window.testStart = function() {
-          esbuild.startService({
+          esbuild.initialize({
             wasmURL: '/esbuild.wasm',
             worker: ${async},
-          }).then(service => {
-            return (${runAllTests})({ esbuild, service })
+          }).then(() => {
+            return (${runAllTests})({ esbuild })
           }).then(() => {
             testDone()
           }).catch(e => {
@@ -171,25 +217,25 @@ for (let format of ['iife', 'esm']) {
 const server = http.createServer((req, res) => {
   if (req.method === 'GET' && req.url) {
     if (req.url === '/lib/browser.js') {
-      res.writeHead(200, { 'Content-Type': 'application/javascript' })
+      res.writeHead(200, { 'Content-Type': 'text/javascript' })
       res.end(js)
       return
     }
 
     if (req.url === '/lib/browser.min.js') {
-      res.writeHead(200, { 'Content-Type': 'application/javascript' })
+      res.writeHead(200, { 'Content-Type': 'text/javascript' })
       res.end(jsMin)
       return
     }
 
     if (req.url === '/esm/browser.js') {
-      res.writeHead(200, { 'Content-Type': 'application/javascript' })
+      res.writeHead(200, { 'Content-Type': 'text/javascript' })
       res.end(esm)
       return
     }
 
     if (req.url === '/esm/browser.min.js') {
-      res.writeHead(200, { 'Content-Type': 'application/javascript' })
+      res.writeHead(200, { 'Content-Type': 'text/javascript' })
       res.end(esmMin)
       return
     }
@@ -206,8 +252,14 @@ const server = http.createServer((req, res) => {
         res.writeHead(200, { 'Content-Type': 'text/html' })
         res.end(`
           <!doctype html>
-          <meta charset="utf8">
-          ${pages[key]}
+          <html>
+            <head>
+              <meta charset="utf8">
+            </head>
+            <body>
+              ${pages[key]}
+            </body>
+          </html>
         `)
         return
       }
