@@ -59,18 +59,18 @@ const buildNeutralLib = (esbuildPath) => {
   fs.writeFileSync(path.join(libDir, 'main.d.ts'), types_ts)
 
   // Get supported platforms
-  const platforms = {}
-  new Function('exports', 'require', childProcess.execFileSync(esbuildPath, [
+  const platforms = { exports: {} }
+  new Function('module', 'exports', 'require', childProcess.execFileSync(esbuildPath, [
     path.join(repoDir, 'lib', 'npm', 'node-platform.ts'),
     '--bundle',
     '--target=' + nodeTarget,
     '--external:esbuild',
     '--platform=node',
     '--log-level=warning',
-  ], { cwd: repoDir }))(platforms, require)
+  ], { cwd: repoDir }))(platforms, platforms.exports, require)
   const optionalDependencies = Object.fromEntries(Object.values({
-    ...platforms.knownWindowsPackages,
-    ...platforms.knownUnixlikePackages,
+    ...platforms.exports.knownWindowsPackages,
+    ...platforms.exports.knownUnixlikePackages,
   }).sort().map(x => [x, version]))
 
   // Update "npm/esbuild/package.json"
@@ -180,8 +180,8 @@ exports.buildWasmLib = async (esbuildPath) => {
     }
 
     // Generate "npm/esbuild-wasm/lib/browser.*"
-    const umdPrefix = `(exports=>{`
-    const umdSuffix = `})(typeof exports==="object"?exports:(typeof self!=="undefined"?self:this).esbuild={});`
+    const umdPrefix = `(module=>{`
+    const umdSuffix = `})(typeof module==="object"?module:{set exports(x){(typeof self!=="undefined"?self:this).esbuild=x}});`
     const browserCJS = childProcess.execFileSync(esbuildPath, [
       path.join(repoDir, 'lib', 'npm', 'browser.ts'),
       '--bundle',
@@ -237,7 +237,7 @@ const buildDenoLib = (esbuildPath) => {
     path.join(repoDir, 'lib', 'deno', 'mod.ts'),
     '--bundle',
     '--outfile=' + path.join(denoDir, 'mod.js'),
-    '--target=es2020',
+    '--target=esnext',
     '--define:ESBUILD_VERSION=' + JSON.stringify(version),
     '--platform=neutral',
     '--log-level=warning',
@@ -323,10 +323,21 @@ exports.installForTests = () => {
   // Evaluate the code
   const ESBUILD_PACKAGE_PATH = path.join(installDir, 'node_modules', 'esbuild')
   const mod = require(ESBUILD_PACKAGE_PATH)
-  mod.ESBUILD_PACKAGE_PATH = ESBUILD_PACKAGE_PATH
+  Object.defineProperty(mod, 'ESBUILD_PACKAGE_PATH', { value: ESBUILD_PACKAGE_PATH })
   return mod
 }
 
+const updateVersionGo = () => {
+  const version_txt = fs.readFileSync(path.join(repoDir, 'version.txt'), 'utf8').trim()
+  const version_go = `package main\n\nconst esbuildVersion = "${version_txt}"\n`
+  const version_go_path = path.join(repoDir, 'cmd', 'esbuild', 'version.go')
+
+  // Update this atomically to avoid issues with this being overwritten during use
+  const temp_path = version_go_path + Math.random().toString(36).slice(1)
+  fs.writeFileSync(temp_path, version_go)
+  fs.renameSync(temp_path, version_go_path)
+}
+
 // This is helpful for ES6 modules which don't have access to __dirname
 exports.dirname = __dirname
 
@@ -336,5 +347,6 @@ if (require.main === module) {
   else if (process.argv.indexOf('--deno') >= 0) buildDenoLib(process.argv[2])
   else if (process.argv.indexOf('--version') >= 0) updateVersionPackageJSON(process.argv[2])
   else if (process.argv.indexOf('--neutral') >= 0) buildNeutralLib(process.argv[2])
+  else if (process.argv.indexOf('--update-version-go') >= 0) updateVersionGo()
   else throw new Error('Expected a flag')
 }
